from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Assignment:
	"""Assignment commands group definition. 21 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("assignment", core, parent)

	@property
	def antennas(self):
		"""antennas commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_antennas'):
			from .Antennas import Antennas
			self._antennas = Antennas(self._core, self._cmd_group)
		return self._antennas

	@property
	def emitters(self):
		"""emitters commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_emitters'):
			from .Emitters import Emitters
			self._emitters = Emitters(self._core, self._cmd_group)
		return self._emitters

	@property
	def generator(self):
		"""generator commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_generator'):
			from .Generator import Generator
			self._generator = Generator(self._core, self._cmd_group)
		return self._generator

	@property
	def group(self):
		"""group commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_group'):
			from .Group import Group
			self._group = Group(self._core, self._cmd_group)
		return self._group

	def clone(self) -> 'Assignment':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Assignment(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Error:
	"""Error commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("error", core, parent)

	def get_all(self) -> str:
		"""SCPI: SYSTem:ERRor:ALL \n
		Snippet: value: str = driver.system.error.get_all() \n
		Queries the error/event queue for all unread items and removes them from the queue. The response is a comma-separated
		list of error number and a short description of the error in FIFO order. Positive error numbers are instrument-dependent.
		Negative error numbers are reserved by the SCPI standard. \n
			:return: all_py: string List of: Error/event_number,'Error/event_description[;Device-dependent info]' If the queue is empty, the response is 0,'No error'
		"""
		response = self._core.io.query_str('SYSTem:ERRor:ALL?')
		return trim_str_response(response)

	def get_count(self) -> str:
		"""SCPI: SYSTem:ERRor:COUNt \n
		Snippet: value: str = driver.system.error.get_count() \n
		Queries the number of entries in the error queue. If the error queue is empty, '0' is returned. \n
			:return: count: string
		"""
		response = self._core.io.query_str('SYSTem:ERRor:COUNt?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Custom:
	"""Custom commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("custom", core, parent)

	@property
	def hpBw(self):
		"""hpBw commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_hpBw'):
			from .HpBw import HpBw
			self._hpBw = HpBw(self._core, self._cmd_group)
		return self._hpBw

	def get_sl_rolloff(self) -> float:
		"""SCPI: ANTenna:MODel:CUSTom:SLRolloff \n
		Snippet: value: float = driver.antenna.model.custom.get_sl_rolloff() \n
		Sets the factor used to calculate the HPBW of the side lobes. \n
			:return: sl_rolloff: float Range: 1 to 45
		"""
		response = self._core.io.query_str('ANTenna:MODel:CUSTom:SLRolloff?')
		return Conversions.str_to_float(response)

	def set_sl_rolloff(self, sl_rolloff: float) -> None:
		"""SCPI: ANTenna:MODel:CUSTom:SLRolloff \n
		Snippet: driver.antenna.model.custom.set_sl_rolloff(sl_rolloff = 1.0) \n
		Sets the factor used to calculate the HPBW of the side lobes. \n
			:param sl_rolloff: float Range: 1 to 45
		"""
		param = Conversions.decimal_value_to_str(sl_rolloff)
		self._core.io.write(f'ANTenna:MODel:CUSTom:SLRolloff {param}')

	def get_sl_scale(self) -> float:
		"""SCPI: ANTenna:MODel:CUSTom:SLSCale \n
		Snippet: value: float = driver.antenna.model.custom.get_sl_scale() \n
		Sets the step size to calculate the power level of the side lobes. \n
			:return: sl_scale: float Range: 0.01 to 10
		"""
		response = self._core.io.query_str('ANTenna:MODel:CUSTom:SLSCale?')
		return Conversions.str_to_float(response)

	def set_sl_scale(self, sl_scale: float) -> None:
		"""SCPI: ANTenna:MODel:CUSTom:SLSCale \n
		Snippet: driver.antenna.model.custom.set_sl_scale(sl_scale = 1.0) \n
		Sets the step size to calculate the power level of the side lobes. \n
			:param sl_scale: float Range: 0.01 to 10
		"""
		param = Conversions.decimal_value_to_str(sl_scale)
		self._core.io.write(f'ANTenna:MODel:CUSTom:SLSCale {param}')

	def get_sl_start(self) -> float:
		"""SCPI: ANTenna:MODel:CUSTom:SLSTart \n
		Snippet: value: float = driver.antenna.model.custom.get_sl_start() \n
		Sets the power level of the first pairs of side lobes. \n
			:return: sl_start: float Range: 1 to 90
		"""
		response = self._core.io.query_str('ANTenna:MODel:CUSTom:SLSTart?')
		return Conversions.str_to_float(response)

	def set_sl_start(self, sl_start: float) -> None:
		"""SCPI: ANTenna:MODel:CUSTom:SLSTart \n
		Snippet: driver.antenna.model.custom.set_sl_start(sl_start = 1.0) \n
		Sets the power level of the first pairs of side lobes. \n
			:param sl_start: float Range: 1 to 90
		"""
		param = Conversions.decimal_value_to_str(sl_start)
		self._core.io.write(f'ANTenna:MODel:CUSTom:SLSTart {param}')

	def clone(self) -> 'Custom':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Custom(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scenario:
	"""Scenario commands group definition. 454 total commands, 16 Subgroups, 13 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scenario", core, parent)

	@property
	def cache(self):
		"""cache commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_cache'):
			from .Cache import Cache
			self._cache = Cache(self._core, self._cmd_group)
		return self._cache

	@property
	def calculate(self):
		"""calculate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_calculate'):
			from .Calculate import Calculate
			self._calculate = Calculate(self._core, self._cmd_group)
		return self._calculate

	@property
	def cemit(self):
		"""cemit commands group. 7 Sub-classes, 14 commands."""
		if not hasattr(self, '_cemit'):
			from .Cemit import Cemit
			self._cemit = Cemit(self._core, self._cmd_group)
		return self._cemit

	@property
	def cpdw(self):
		"""cpdw commands group. 2 Sub-classes, 13 commands."""
		if not hasattr(self, '_cpdw'):
			from .Cpdw import Cpdw
			self._cpdw = Cpdw(self._core, self._cmd_group)
		return self._cpdw

	@property
	def csequence(self):
		"""csequence commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_csequence'):
			from .Csequence import Csequence
			self._csequence = Csequence(self._core, self._cmd_group)
		return self._csequence

	@property
	def df(self):
		"""df commands group. 14 Sub-classes, 14 commands."""
		if not hasattr(self, '_df'):
			from .Df import Df
			self._df = Df(self._core, self._cmd_group)
		return self._df

	@property
	def emitter(self):
		"""emitter commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_emitter'):
			from .Emitter import Emitter
			self._emitter = Emitter(self._core, self._cmd_group)
		return self._emitter

	@property
	def generator(self):
		"""generator commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_generator'):
			from .Generator import Generator
			self._generator = Generator(self._core, self._cmd_group)
		return self._generator

	@property
	def ilCache(self):
		"""ilCache commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_ilCache'):
			from .IlCache import IlCache
			self._ilCache = IlCache(self._core, self._cmd_group)
		return self._ilCache

	@property
	def interleave(self):
		"""interleave commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_interleave'):
			from .Interleave import Interleave
			self._interleave = Interleave(self._core, self._cmd_group)
		return self._interleave

	@property
	def localized(self):
		"""localized commands group. 13 Sub-classes, 14 commands."""
		if not hasattr(self, '_localized'):
			from .Localized import Localized
			self._localized = Localized(self._core, self._cmd_group)
		return self._localized

	@property
	def output(self):
		"""output commands group. 7 Sub-classes, 11 commands."""
		if not hasattr(self, '_output'):
			from .Output import Output
			self._output = Output(self._core, self._cmd_group)
		return self._output

	@property
	def pdw(self):
		"""pdw commands group. 2 Sub-classes, 5 commands."""
		if not hasattr(self, '_pdw'):
			from .Pdw import Pdw
			self._pdw = Pdw(self._core, self._cmd_group)
		return self._pdw

	@property
	def sequence(self):
		"""sequence commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_sequence'):
			from .Sequence import Sequence
			self._sequence = Sequence(self._core, self._cmd_group)
		return self._sequence

	@property
	def trigger(self):
		"""trigger commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import Trigger
			self._trigger = Trigger(self._core, self._cmd_group)
		return self._trigger

	@property
	def volatile(self):
		"""volatile commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_volatile'):
			from .Volatile import Volatile
			self._volatile = Volatile(self._core, self._cmd_group)
		return self._volatile

	def get_catalog(self) -> str:
		"""SCPI: SCENario:CATalog \n
		Snippet: value: str = driver.scenario.get_catalog() \n
		Queries the available repository elements in the database. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SCENario:CATalog?')
		return trim_str_response(response)

	def get_comment(self) -> str:
		"""SCPI: SCENario:COMMent \n
		Snippet: value: str = driver.scenario.get_comment() \n
		Adds a description to the selected repository element. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('SCENario:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: SCENario:COMMent \n
		Snippet: driver.scenario.set_comment(comment = '1') \n
		Adds a description to the selected repository element. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'SCENario:COMMent {param}')

	def set_create(self, create: str) -> None:
		"""SCPI: SCENario:CREate \n
		Snippet: driver.scenario.set_create(create = '1') \n
		Creates a repository element with the selected name. \n
			:param create: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(create)
		self._core.io.write(f'SCENario:CREate {param}')

	def get_id(self) -> float:
		"""SCPI: SCENario:ID \n
		Snippet: value: float = driver.scenario.get_id() \n
		Queries the database identifier of the selected scenario. \n
			:return: idn: float
		"""
		response = self._core.io.query_str('SCENario:ID?')
		return Conversions.str_to_float(response)

	def get_name(self) -> str:
		"""SCPI: SCENario:NAME \n
		Snippet: value: str = driver.scenario.get_name() \n
		Renames the selected repository element. \n
			:return: name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		response = self._core.io.query_str('SCENario:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: SCENario:NAME \n
		Snippet: driver.scenario.set_name(name = '1') \n
		Renames the selected repository element. \n
			:param name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'SCENario:NAME {param}')

	def set_remove(self, remove: str) -> None:
		"""SCPI: SCENario:REMove \n
		Snippet: driver.scenario.set_remove(remove = '1') \n
		Removes the selected element from the workspace. The element must not reference any child elements. Remove the referenced
		elements first. \n
			:param remove: No help available
		"""
		param = Conversions.value_to_quoted_str(remove)
		self._core.io.write(f'SCENario:REMove {param}')

	def set_sanitize(self, sanitize: enums.SanitizeScenario) -> None:
		"""SCPI: SCENario:SANitize \n
		Snippet: driver.scenario.set_sanitize(sanitize = enums.SanitizeScenario.ALL) \n
		Removes uploaded waveforms from the hard disk of the signal generator. \n
			:param sanitize: SCENario| REPository| ALL SCENario Removes the current scenario waveforms REPository Removes the waveforms of all scenarios from the current repository ALL Removes all waveforms created by the R&S Pulse Sequencer
		"""
		param = Conversions.enum_scalar_to_str(sanitize, enums.SanitizeScenario)
		self._core.io.write(f'SCENario:SANitize {param}')

	def get_select(self) -> str:
		"""SCPI: SCENario:SELect \n
		Snippet: value: str = driver.scenario.get_select() \n
		Selects the repository element to which the subsequent commands apply. \n
			:return: select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		response = self._core.io.query_str('SCENario:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: SCENario:SELect \n
		Snippet: driver.scenario.set_select(select = '1') \n
		Selects the repository element to which the subsequent commands apply. \n
			:param select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'SCENario:SELect {param}')

	def start(self) -> None:
		"""SCPI: SCENario:STARt \n
		Snippet: driver.scenario.start() \n
		Starts/stops signal generation. \n
		"""
		self._core.io.write(f'SCENario:STARt')

	def start_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:STARt \n
		Snippet: driver.scenario.start_with_opc() \n
		Starts/stops signal generation. \n
		Same as start, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:STARt', opc_timeout_ms)

	# noinspection PyTypeChecker
	def get_state(self) -> enums.State:
		"""SCPI: SCENario:STATe \n
		Snippet: value: enums.State = driver.scenario.get_state() \n
		Queries the current scenario status. \n
			:return: state: IDLE| RUN
		"""
		response = self._core.io.query_str('SCENario:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.State)

	def stop(self) -> None:
		"""SCPI: SCENario:STOP \n
		Snippet: driver.scenario.stop() \n
		Starts/stops signal generation. \n
		"""
		self._core.io.write(f'SCENario:STOP')

	def stop_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:STOP \n
		Snippet: driver.scenario.stop_with_opc() \n
		Starts/stops signal generation. \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:STOP', opc_timeout_ms)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.ScenarioType:
		"""SCPI: SCENario:TYPE \n
		Snippet: value: enums.ScenarioType = driver.scenario.get_type_py() \n
		Sets the scenario type. \n
			:return: type_py: SEQuence| CSEQuence| EMITter| CEMitter| LOCalized| DF| PDW | WAVeform
		"""
		response = self._core.io.query_str('SCENario:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.ScenarioType)

	def set_type_py(self, type_py: enums.ScenarioType) -> None:
		"""SCPI: SCENario:TYPE \n
		Snippet: driver.scenario.set_type_py(type_py = enums.ScenarioType.CEMitter) \n
		Sets the scenario type. \n
			:param type_py: SEQuence| CSEQuence| EMITter| CEMitter| LOCalized| DF| PDW | WAVeform
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.ScenarioType)
		self._core.io.write(f'SCENario:TYPE {param}')

	def get_waveform(self) -> str:
		"""SCPI: SCENario:WAVeform \n
		Snippet: value: str = driver.scenario.get_waveform() \n
		Specify the name of the 'Signal Generation' output file. \n
			:return: waveform: string
		"""
		response = self._core.io.query_str('SCENario:WAVeform?')
		return trim_str_response(response)

	def set_waveform(self, waveform: str) -> None:
		"""SCPI: SCENario:WAVeform \n
		Snippet: driver.scenario.set_waveform(waveform = '1') \n
		Specify the name of the 'Signal Generation' output file. \n
			:param waveform: string
		"""
		param = Conversions.value_to_quoted_str(waveform)
		self._core.io.write(f'SCENario:WAVeform {param}')

	def clone(self) -> 'Scenario':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Scenario(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Overshoot:
	"""Overshoot commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("overshoot", core, parent)

	def get_decay(self) -> float:
		"""SCPI: PULSe:OVERshoot:DECay \n
		Snippet: value: float = driver.pulse.overshoot.get_decay() \n
		Sets the number of peaks. \n
			:return: decay: float Range: 1 to 100
		"""
		response = self._core.io.query_str('PULSe:OVERshoot:DECay?')
		return Conversions.str_to_float(response)

	def set_decay(self, decay: float) -> None:
		"""SCPI: PULSe:OVERshoot:DECay \n
		Snippet: driver.pulse.overshoot.set_decay(decay = 1.0) \n
		Sets the number of peaks. \n
			:param decay: float Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(decay)
		self._core.io.write(f'PULSe:OVERshoot:DECay {param}')

	def get_value(self) -> float:
		"""SCPI: PULSe:OVERshoot \n
		Snippet: value: float = driver.pulse.overshoot.get_value() \n
		Sets the overshoot level value. \n
			:return: overshoot: float Range: 0 to 50
		"""
		response = self._core.io.query_str('PULSe:OVERshoot?')
		return Conversions.str_to_float(response)

	def set_value(self, overshoot: float) -> None:
		"""SCPI: PULSe:OVERshoot \n
		Snippet: driver.pulse.overshoot.set_value(overshoot = 1.0) \n
		Sets the overshoot level value. \n
			:param overshoot: float Range: 0 to 50
		"""
		param = Conversions.decimal_value_to_str(overshoot)
		self._core.io.write(f'PULSe:OVERshoot {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Lissajous:
	"""Lissajous commands group definition. 7 total commands, 0 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lissajous", core, parent)

	def get_am_px(self) -> float:
		"""SCPI: SCAN:LISSajous:AMPX \n
		Snippet: value: float = driver.scan.lissajous.get_am_px() \n
		Sets the magnitudes of two harmonic vibrations. \n
			:return: am_px: No help available
		"""
		response = self._core.io.query_str('SCAN:LISSajous:AMPX?')
		return Conversions.str_to_float(response)

	def set_am_px(self, am_px: float) -> None:
		"""SCPI: SCAN:LISSajous:AMPX \n
		Snippet: driver.scan.lissajous.set_am_px(am_px = 1.0) \n
		Sets the magnitudes of two harmonic vibrations. \n
			:param am_px: float Range: 0.01 to 45
		"""
		param = Conversions.decimal_value_to_str(am_px)
		self._core.io.write(f'SCAN:LISSajous:AMPX {param}')

	def get_am_pz(self) -> float:
		"""SCPI: SCAN:LISSajous:AMPZ \n
		Snippet: value: float = driver.scan.lissajous.get_am_pz() \n
		Sets the magnitudes of two harmonic vibrations. \n
			:return: am_pz: float Range: 0.01 to 45
		"""
		response = self._core.io.query_str('SCAN:LISSajous:AMPZ?')
		return Conversions.str_to_float(response)

	def set_am_pz(self, am_pz: float) -> None:
		"""SCPI: SCAN:LISSajous:AMPZ \n
		Snippet: driver.scan.lissajous.set_am_pz(am_pz = 1.0) \n
		Sets the magnitudes of two harmonic vibrations. \n
			:param am_pz: float Range: 0.01 to 45
		"""
		param = Conversions.decimal_value_to_str(am_pz)
		self._core.io.write(f'SCAN:LISSajous:AMPZ {param}')

	def get_freq(self) -> float:
		"""SCPI: SCAN:LISSajous:FREQ \n
		Snippet: value: float = driver.scan.lissajous.get_freq() \n
		Sets the base frequency. \n
			:return: freq: float Range: 0.01 to 1000
		"""
		response = self._core.io.query_str('SCAN:LISSajous:FREQ?')
		return Conversions.str_to_float(response)

	def set_freq(self, freq: float) -> None:
		"""SCPI: SCAN:LISSajous:FREQ \n
		Snippet: driver.scan.lissajous.set_freq(freq = 1.0) \n
		Sets the base frequency. \n
			:param freq: float Range: 0.01 to 1000
		"""
		param = Conversions.decimal_value_to_str(freq)
		self._core.io.write(f'SCAN:LISSajous:FREQ {param}')

	def get_phix(self) -> float:
		"""SCPI: SCAN:LISSajous:PHIX \n
		Snippet: value: float = driver.scan.lissajous.get_phix() \n
		Sets the phases of the two harmonic vibrations. \n
			:return: phix: No help available
		"""
		response = self._core.io.query_str('SCAN:LISSajous:PHIX?')
		return Conversions.str_to_float(response)

	def set_phix(self, phix: float) -> None:
		"""SCPI: SCAN:LISSajous:PHIX \n
		Snippet: driver.scan.lissajous.set_phix(phix = 1.0) \n
		Sets the phases of the two harmonic vibrations. \n
			:param phix: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(phix)
		self._core.io.write(f'SCAN:LISSajous:PHIX {param}')

	def get_phiz(self) -> float:
		"""SCPI: SCAN:LISSajous:PHIZ \n
		Snippet: value: float = driver.scan.lissajous.get_phiz() \n
		Sets the phases of the two harmonic vibrations. \n
			:return: phiz: float Range: 0 to 360
		"""
		response = self._core.io.query_str('SCAN:LISSajous:PHIZ?')
		return Conversions.str_to_float(response)

	def set_phiz(self, phiz: float) -> None:
		"""SCPI: SCAN:LISSajous:PHIZ \n
		Snippet: driver.scan.lissajous.set_phiz(phiz = 1.0) \n
		Sets the phases of the two harmonic vibrations. \n
			:param phiz: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(phiz)
		self._core.io.write(f'SCAN:LISSajous:PHIZ {param}')

	def get_xfactor(self) -> float:
		"""SCPI: SCAN:LISSajous:XFACtor \n
		Snippet: value: float = driver.scan.lissajous.get_xfactor() \n
		Sets the ratio between the two angular frequencies. \n
			:return: xfactor: No help available
		"""
		response = self._core.io.query_str('SCAN:LISSajous:XFACtor?')
		return Conversions.str_to_float(response)

	def set_xfactor(self, xfactor: float) -> None:
		"""SCPI: SCAN:LISSajous:XFACtor \n
		Snippet: driver.scan.lissajous.set_xfactor(xfactor = 1.0) \n
		Sets the ratio between the two angular frequencies. \n
			:param xfactor: float Range: 1 to 10
		"""
		param = Conversions.decimal_value_to_str(xfactor)
		self._core.io.write(f'SCAN:LISSajous:XFACtor {param}')

	def get_zfactor(self) -> float:
		"""SCPI: SCAN:LISSajous:ZFACtor \n
		Snippet: value: float = driver.scan.lissajous.get_zfactor() \n
		Sets the ratio between the two angular frequencies. \n
			:return: zfactor: float Range: 1 to 10
		"""
		response = self._core.io.query_str('SCAN:LISSajous:ZFACtor?')
		return Conversions.str_to_float(response)

	def set_zfactor(self, zfactor: float) -> None:
		"""SCPI: SCAN:LISSajous:ZFACtor \n
		Snippet: driver.scan.lissajous.set_zfactor(zfactor = 1.0) \n
		Sets the ratio between the two angular frequencies. \n
			:param zfactor: float Range: 1 to 10
		"""
		param = Conversions.decimal_value_to_str(zfactor)
		self._core.io.write(f'SCAN:LISSajous:ZFACtor {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pdw:
	"""Pdw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdw", core, parent)

	def get_center(self) -> float:
		"""SCPI: WAVeform:PDW:CENTer \n
		Snippet: value: float = driver.waveform.pdw.get_center() \n
		During the import of PDW list files, the software evaluates the frequency information in the file and calculates the
		center frequency of all pulses. The center frequency is calculated as the middle frequency between the min and the max
		frequency values included in the PDW file. Chirp frequency deviations are also considered. The pulses are calculated
		relatively to this center frequency. If the actual frequency of the generator differs from the calculated one, use this
		command to set the center frequency of the generator. \n
			:return: center: float Range: 0 to 4e+10
		"""
		response = self._core.io.query_str('WAVeform:PDW:CENTer?')
		return Conversions.str_to_float(response)

	def set_center(self, center: float) -> None:
		"""SCPI: WAVeform:PDW:CENTer \n
		Snippet: driver.waveform.pdw.set_center(center = 1.0) \n
		During the import of PDW list files, the software evaluates the frequency information in the file and calculates the
		center frequency of all pulses. The center frequency is calculated as the middle frequency between the min and the max
		frequency values included in the PDW file. Chirp frequency deviations are also considered. The pulses are calculated
		relatively to this center frequency. If the actual frequency of the generator differs from the calculated one, use this
		command to set the center frequency of the generator. \n
			:param center: float Range: 0 to 4e+10
		"""
		param = Conversions.decimal_value_to_str(center)
		self._core.io.write(f'WAVeform:PDW:CENTer {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Elevation:
	"""Elevation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("elevation", core, parent)

	def get_step(self) -> float:
		"""SCPI: SCAN:HELical:ELEVation:STEP \n
		Snippet: value: float = driver.scan.helical.elevation.get_step() \n
		Sets the step width with that the antenna changes its elevation. \n
			:return: step: float Range: 0.01 to 11.25, Unit: degree
		"""
		response = self._core.io.query_str('SCAN:HELical:ELEVation:STEP?')
		return Conversions.str_to_float(response)

	def set_step(self, step: float) -> None:
		"""SCPI: SCAN:HELical:ELEVation:STEP \n
		Snippet: driver.scan.helical.elevation.set_step(step = 1.0) \n
		Sets the step width with that the antenna changes its elevation. \n
			:param step: float Range: 0.01 to 11.25, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(step)
		self._core.io.write(f'SCAN:HELical:ELEVation:STEP {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Variable:
	"""Variable commands group definition. 5 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("variable", core, parent)

	@property
	def select(self):
		"""select commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_select'):
			from .Select import Select
			self._select = Select(self._core, self._cmd_group)
		return self._select

	def get_catalog(self) -> str:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:CATalog \n
		Snippet: value: str = driver.pulse.mop.plugin.variable.get_catalog() \n
		Queries the variables used in the plugin. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('PULSe:MOP:PLUGin:VARiable:CATalog?')
		return trim_str_response(response)

	def reset(self) -> None:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:RESet \n
		Snippet: driver.pulse.mop.plugin.variable.reset() \n
		Resets the variable values to the defaults. \n
		"""
		self._core.io.write(f'PULSe:MOP:PLUGin:VARiable:RESet')

	def reset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:RESet \n
		Snippet: driver.pulse.mop.plugin.variable.reset_with_opc() \n
		Resets the variable values to the defaults. \n
		Same as reset, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'PULSe:MOP:PLUGin:VARiable:RESet', opc_timeout_ms)

	def get_value(self) -> str:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:VALue \n
		Snippet: value: str = driver.pulse.mop.plugin.variable.get_value() \n
		Sets the values of the selected variable. \n
			:return: value: string
		"""
		response = self._core.io.query_str('PULSe:MOP:PLUGin:VARiable:VALue?')
		return trim_str_response(response)

	def set_value(self, value: str) -> None:
		"""SCPI: PULSe:MOP:PLUGin:VARiable:VALue \n
		Snippet: driver.pulse.mop.plugin.variable.set_value(value = '1') \n
		Sets the values of the selected variable. \n
			:param value: string
		"""
		param = Conversions.value_to_quoted_str(value)
		self._core.io.write(f'PULSe:MOP:PLUGin:VARiable:VALue {param}')

	def clone(self) -> 'Variable':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Variable(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sequence:
	"""Sequence commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sequence", core, parent)

	def clear(self) -> None:
		"""SCPI: SCENario:SEQuence:CLEar \n
		Snippet: driver.scenario.sequence.clear() \n
		No command help available \n
		"""
		self._core.io.write(f'SCENario:SEQuence:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:SEQuence:CLEar \n
		Snippet: driver.scenario.sequence.clear_with_opc() \n
		No command help available \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:SEQuence:CLEar', opc_timeout_ms)

	def get_value(self) -> str:
		"""SCPI: SCENario:SEQuence \n
		Snippet: value: str = driver.scenario.sequence.get_value() \n
		Assigns a pulse sequence, see method RsPulseSeq.Sequence.catalog. \n
			:return: sequence: string
		"""
		response = self._core.io.query_str('SCENario:SEQuence?')
		return trim_str_response(response)

	def set_value(self, sequence: str) -> None:
		"""SCPI: SCENario:SEQuence \n
		Snippet: driver.scenario.sequence.set_value(sequence = '1') \n
		Assigns a pulse sequence, see method RsPulseSeq.Sequence.catalog. \n
			:param sequence: string
		"""
		param = Conversions.value_to_quoted_str(sequence)
		self._core.io.write(f'SCENario:SEQuence {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class View:
	"""View commands group definition. 6 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("view", core, parent)

	@property
	def move(self):
		"""move commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_move'):
			from .Move import Move
			self._move = Move(self._core, self._cmd_group)
		return self._move

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_time'):
			from .Time import Time
			self._time = Time(self._core, self._cmd_group)
		return self._time

	# noinspection PyTypeChecker
	def get_count(self) -> enums.ViewCount:
		"""SCPI: IMPort:VIEW:COUNt \n
		Snippet: value: enums.ViewCount = driver.importPy.view.get_count() \n
		Sets the entries per page to be displayed. \n
			:return: count: 50| 100| 500| 1000| 5000| 10000| 50000| 100000
		"""
		response = self._core.io.query_str('IMPort:VIEW:COUNt?')
		return Conversions.str_to_scalar_enum(response, enums.ViewCount)

	def set_count(self, count: enums.ViewCount) -> None:
		"""SCPI: IMPort:VIEW:COUNt \n
		Snippet: driver.importPy.view.set_count(count = enums.ViewCount._100) \n
		Sets the entries per page to be displayed. \n
			:param count: 50| 100| 500| 1000| 5000| 10000| 50000| 100000
		"""
		param = Conversions.enum_scalar_to_str(count, enums.ViewCount)
		self._core.io.write(f'IMPort:VIEW:COUNt {param}')

	def clone(self) -> 'View':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = View(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Random:
	"""Random commands group definition. 9 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("random", core, parent)

	@property
	def normal(self):
		"""normal commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_normal'):
			from .Normal import Normal
			self._normal = Normal(self._core, self._cmd_group)
		return self._normal

	@property
	def u(self):
		"""u commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_u'):
			from .U import U
			self._u = U(self._core, self._cmd_group)
		return self._u

	@property
	def uniform(self):
		"""uniform commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_uniform'):
			from .Uniform import Uniform
			self._uniform = Uniform(self._core, self._cmd_group)
		return self._uniform

	# noinspection PyTypeChecker
	def get_distribution(self) -> enums.RandomDistribution:
		"""SCPI: IPM:RANDom:DISTribution \n
		Snippet: value: enums.RandomDistribution = driver.ipm.random.get_distribution() \n
		Sets the distribution function. \n
			:return: distribution: UNIForm| NORMal| U
		"""
		response = self._core.io.query_str('IPM:RANDom:DISTribution?')
		return Conversions.str_to_scalar_enum(response, enums.RandomDistribution)

	def set_distribution(self, distribution: enums.RandomDistribution) -> None:
		"""SCPI: IPM:RANDom:DISTribution \n
		Snippet: driver.ipm.random.set_distribution(distribution = enums.RandomDistribution.NORMal) \n
		Sets the distribution function. \n
			:param distribution: UNIForm| NORMal| U
		"""
		param = Conversions.enum_scalar_to_str(distribution, enums.RandomDistribution)
		self._core.io.write(f'IPM:RANDom:DISTribution {param}')

	def clone(self) -> 'Random':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Random(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ovl:
	"""Ovl commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ovl", core, parent)

	def get_variable(self) -> str:
		"""SCPI: SEQuence:ITEM:OVL:VARiable \n
		Snippet: value: str = driver.sequence.item.ovl.get_variable() \n
		Sets a variable. \n
			:return: variable: string
		"""
		response = self._core.io.query_str('SEQuence:ITEM:OVL:VARiable?')
		return trim_str_response(response)

	def set_variable(self, variable: str) -> None:
		"""SCPI: SEQuence:ITEM:OVL:VARiable \n
		Snippet: driver.sequence.item.ovl.set_variable(variable = '1') \n
		Sets a variable. \n
			:param variable: string
		"""
		param = Conversions.value_to_quoted_str(variable)
		self._core.io.write(f'SEQuence:ITEM:OVL:VARiable {param}')

	def get_wtime(self) -> float:
		"""SCPI: SEQuence:ITEM:OVL:WTIMe \n
		Snippet: value: float = driver.sequence.item.ovl.get_wtime() \n
		Sets the duration of the overlay. \n
			:return: wtime: float Range: 0 to 3600, Unit: sec
		"""
		response = self._core.io.query_str('SEQuence:ITEM:OVL:WTIMe?')
		return Conversions.str_to_float(response)

	def set_wtime(self, wtime: float) -> None:
		"""SCPI: SEQuence:ITEM:OVL:WTIMe \n
		Snippet: driver.sequence.item.ovl.set_wtime(wtime = 1.0) \n
		Sets the duration of the overlay. \n
			:param wtime: float Range: 0 to 3600, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(wtime)
		self._core.io.write(f'SEQuence:ITEM:OVL:WTIMe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Enable:
	"""Enable commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("enable", core, parent)

	def get_interleave(self) -> bool:
		"""SCPI: SCENario:CACHe:REPository:ENABle:INTerleave \n
		Snippet: value: bool = driver.scenario.cache.repository.enable.get_interleave() \n
		Enables file storage in the repository when interleaving is active. \n
			:return: interleave: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:CACHe:REPository:ENABle:INTerleave?')
		return Conversions.str_to_bool(response)

	def set_interleave(self, interleave: bool) -> None:
		"""SCPI: SCENario:CACHe:REPository:ENABle:INTerleave \n
		Snippet: driver.scenario.cache.repository.enable.set_interleave(interleave = False) \n
		Enables file storage in the repository when interleaving is active. \n
			:param interleave: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(interleave)
		self._core.io.write(f'SCENario:CACHe:REPository:ENABle:INTerleave {param}')

	def get_value(self) -> bool:
		"""SCPI: SCENario:CACHe:REPository:ENABle \n
		Snippet: value: bool = driver.scenario.cache.repository.enable.get_value() \n
		Enables file storage in the repository. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:CACHe:REPository:ENABle?')
		return Conversions.str_to_bool(response)

	def set_value(self, enable: bool) -> None:
		"""SCPI: SCENario:CACHe:REPository:ENABle \n
		Snippet: driver.scenario.cache.repository.enable.set_value(enable = False) \n
		Enables file storage in the repository. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:CACHe:REPository:ENABle {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ratio:
	"""Ratio commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ratio", core, parent)

	def get_maximum(self) -> float:
		"""SCPI: WAVeform:BEMitter:PRI:RATio:MAXimum \n
		Snippet: value: float = driver.waveform.bemitter.pri.ratio.get_maximum() \n
		Sets the value range for the PRI/PW ratio. \n
			:return: maximum: float Range: 10 to 1000
		"""
		response = self._core.io.query_str('WAVeform:BEMitter:PRI:RATio:MAXimum?')
		return Conversions.str_to_float(response)

	def set_maximum(self, maximum: float) -> None:
		"""SCPI: WAVeform:BEMitter:PRI:RATio:MAXimum \n
		Snippet: driver.waveform.bemitter.pri.ratio.set_maximum(maximum = 1.0) \n
		Sets the value range for the PRI/PW ratio. \n
			:param maximum: float Range: 10 to 1000
		"""
		param = Conversions.decimal_value_to_str(maximum)
		self._core.io.write(f'WAVeform:BEMitter:PRI:RATio:MAXimum {param}')

	def get_minimum(self) -> float:
		"""SCPI: WAVeform:BEMitter:PRI:RATio:MINimum \n
		Snippet: value: float = driver.waveform.bemitter.pri.ratio.get_minimum() \n
		Sets the value range for the PRI/PW ratio. \n
			:return: minimum: No help available
		"""
		response = self._core.io.query_str('WAVeform:BEMitter:PRI:RATio:MINimum?')
		return Conversions.str_to_float(response)

	def set_minimum(self, minimum: float) -> None:
		"""SCPI: WAVeform:BEMitter:PRI:RATio:MINimum \n
		Snippet: driver.waveform.bemitter.pri.ratio.set_minimum(minimum = 1.0) \n
		Sets the value range for the PRI/PW ratio. \n
			:param minimum: float Range: 10 to 1000
		"""
		param = Conversions.decimal_value_to_str(minimum)
		self._core.io.write(f'WAVeform:BEMitter:PRI:RATio:MINimum {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rlist:
	"""Rlist commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rlist", core, parent)

	# noinspection PyTypeChecker
	def get_base(self) -> enums.BaseDomainB:
		"""SCPI: IPM:RLISt:BASE \n
		Snippet: value: enums.BaseDomainB = driver.ipm.rlist.get_base() \n
		Sets the IPM profile base and defines how the increments repetition is defined. \n
			:return: base: LENGth| TIME LENGth Increments are repeated several times, as set with the command method RsPulseSeq.Ipm.Rlist.burst. TIME Increments are repeated for the defined time duration, as set with the command method RsPulseSeq.Ipm.Rlist.period.
		"""
		response = self._core.io.query_str('IPM:RLISt:BASE?')
		return Conversions.str_to_scalar_enum(response, enums.BaseDomainB)

	def set_base(self, base: enums.BaseDomainB) -> None:
		"""SCPI: IPM:RLISt:BASE \n
		Snippet: driver.ipm.rlist.set_base(base = enums.BaseDomainB.LENGth) \n
		Sets the IPM profile base and defines how the increments repetition is defined. \n
			:param base: LENGth| TIME LENGth Increments are repeated several times, as set with the command method RsPulseSeq.Ipm.Rlist.burst. TIME Increments are repeated for the defined time duration, as set with the command method RsPulseSeq.Ipm.Rlist.period.
		"""
		param = Conversions.enum_scalar_to_str(base, enums.BaseDomainB)
		self._core.io.write(f'IPM:RLISt:BASE {param}')

	def get_burst(self) -> float:
		"""SCPI: IPM:RLISt:BURSt \n
		Snippet: value: float = driver.ipm.rlist.get_burst() \n
		Defines how many times an increment is repeated. \n
			:return: burst: float Range: 1 to 8192
		"""
		response = self._core.io.query_str('IPM:RLISt:BURSt?')
		return Conversions.str_to_float(response)

	def set_burst(self, burst: float) -> None:
		"""SCPI: IPM:RLISt:BURSt \n
		Snippet: driver.ipm.rlist.set_burst(burst = 1.0) \n
		Defines how many times an increment is repeated. \n
			:param burst: float Range: 1 to 8192
		"""
		param = Conversions.decimal_value_to_str(burst)
		self._core.io.write(f'IPM:RLISt:BURSt {param}')

	def get_period(self) -> float:
		"""SCPI: IPM:RLISt:PERiod \n
		Snippet: value: float = driver.ipm.rlist.get_period() \n
		Sets how long an increment is repeated. \n
			:return: period: float Range: 1e-09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:RLISt:PERiod?')
		return Conversions.str_to_float(response)

	def set_period(self, period: float) -> None:
		"""SCPI: IPM:RLISt:PERiod \n
		Snippet: driver.ipm.rlist.set_period(period = 1.0) \n
		Sets how long an increment is repeated. \n
			:param period: float Range: 1e-09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(period)
		self._core.io.write(f'IPM:RLISt:PERiod {param}')

	def get_reuse(self) -> bool:
		"""SCPI: IPM:RLISt:REUSe \n
		Snippet: value: bool = driver.ipm.rlist.get_reuse() \n
		If disabled, each value is used only once. \n
			:return: reuse: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('IPM:RLISt:REUSe?')
		return Conversions.str_to_bool(response)

	def set_reuse(self, reuse: bool) -> None:
		"""SCPI: IPM:RLISt:REUSe \n
		Snippet: driver.ipm.rlist.set_reuse(reuse = False) \n
		If disabled, each value is used only once. \n
			:param reuse: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(reuse)
		self._core.io.write(f'IPM:RLISt:REUSe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Polar:
	"""Polar commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("polar", core, parent)

	@property
	def log(self):
		"""log commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_log'):
			from .Log import Log
			self._log = Log(self._core, self._cmd_group)
		return self._log

	def set_cut(self, cut: enums.PolarCut) -> None:
		"""SCPI: PLOT:POLar:CUT \n
		Snippet: driver.plot.polar.set_cut(cut = enums.PolarCut.XY) \n
		Sets the diagram cut. \n
			:param cut: XY| YZ
		"""
		param = Conversions.enum_scalar_to_str(cut, enums.PolarCut)
		self._core.io.write(f'PLOT:POLar:CUT {param}')

	def set_type_py(self, type_py: enums.PolarType) -> None:
		"""SCPI: PLOT:POLar:TYPE \n
		Snippet: driver.plot.polar.set_type_py(type_py = enums.PolarType.CARTesian) \n
		Sets the coordinates of the 2D antenna pattern diagram. \n
			:param type_py: POLar| CARTesian
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.PolarType)
		self._core.io.write(f'PLOT:POLar:TYPE {param}')

	def clone(self) -> 'Polar':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Polar(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Entry:
	"""Entry commands group definition. 11 total commands, 1 Subgroups, 10 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("entry", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	def get_azimuth(self) -> float:
		"""SCPI: SCAN:CUSTom:ENTRy:AZIMuth \n
		Snippet: value: float = driver.scan.custom.entry.get_azimuth() \n
		Sets the azimuth of the scan position. \n
			:return: azimuth: float Range: -180 to 180
		"""
		response = self._core.io.query_str('SCAN:CUSTom:ENTRy:AZIMuth?')
		return Conversions.str_to_float(response)

	def set_azimuth(self, azimuth: float) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:AZIMuth \n
		Snippet: driver.scan.custom.entry.set_azimuth(azimuth = 1.0) \n
		Sets the azimuth of the scan position. \n
			:param azimuth: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(azimuth)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:AZIMuth {param}')

	def clear(self) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:CLEar \n
		Snippet: driver.scan.custom.entry.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'SCAN:CUSTom:ENTRy:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:CLEar \n
		Snippet: driver.scan.custom.entry.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCAN:CUSTom:ENTRy:CLEar', opc_timeout_ms)

	def get_count(self) -> float:
		"""SCPI: SCAN:CUSTom:ENTRy:COUNt \n
		Snippet: value: float = driver.scan.custom.entry.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('SCAN:CUSTom:ENTRy:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:DELete \n
		Snippet: driver.scan.custom.entry.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:DELete {param}')

	def get_dwell(self) -> float:
		"""SCPI: SCAN:CUSTom:ENTRy:DWELl \n
		Snippet: value: float = driver.scan.custom.entry.get_dwell() \n
		Sets how long the scan stays in a position. \n
			:return: dwell: float Range: 0 to 3600
		"""
		response = self._core.io.query_str('SCAN:CUSTom:ENTRy:DWELl?')
		return Conversions.str_to_float(response)

	def set_dwell(self, dwell: float) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:DWELl \n
		Snippet: driver.scan.custom.entry.set_dwell(dwell = 1.0) \n
		Sets how long the scan stays in a position. \n
			:param dwell: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(dwell)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:DWELl {param}')

	def get_elevation(self) -> float:
		"""SCPI: SCAN:CUSTom:ENTRy:ELEVation \n
		Snippet: value: float = driver.scan.custom.entry.get_elevation() \n
		Sets the elevation of the scan position. \n
			:return: elevation: float Range: -90 to 90
		"""
		response = self._core.io.query_str('SCAN:CUSTom:ENTRy:ELEVation?')
		return Conversions.str_to_float(response)

	def set_elevation(self, elevation: float) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:ELEVation \n
		Snippet: driver.scan.custom.entry.set_elevation(elevation = 1.0) \n
		Sets the elevation of the scan position. \n
			:param elevation: float Range: -90 to 90
		"""
		param = Conversions.decimal_value_to_str(elevation)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:ELEVation {param}')

	def set_insert(self, insert: float) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:INSert \n
		Snippet: driver.scan.custom.entry.set_insert(insert = 1.0) \n
		Inserts a new item before the selected one. \n
			:param insert: float
		"""
		param = Conversions.decimal_value_to_str(insert)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:INSert {param}')

	def get_jump_type(self) -> bool:
		"""SCPI: SCAN:CUSTom:ENTRy:JUMPtype \n
		Snippet: value: bool = driver.scan.custom.entry.get_jump_type() \n
		Defines how to move to the next position, either with a jump or with a transition. For transitions, you need to define a
		transition time. \n
			:return: jump_type: ON| OFF| 1| 0 ON | 1 Jump enabled. OFF | 0 Transition enabled.
		"""
		response = self._core.io.query_str('SCAN:CUSTom:ENTRy:JUMPtype?')
		return Conversions.str_to_bool(response)

	def set_jump_type(self, jump_type: bool) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:JUMPtype \n
		Snippet: driver.scan.custom.entry.set_jump_type(jump_type = False) \n
		Defines how to move to the next position, either with a jump or with a transition. For transitions, you need to define a
		transition time. \n
			:param jump_type: ON| OFF| 1| 0 ON | 1 Jump enabled. OFF | 0 Transition enabled.
		"""
		param = Conversions.bool_to_str(jump_type)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:JUMPtype {param}')

	def get_select(self) -> float:
		"""SCPI: SCAN:CUSTom:ENTRy:SELect \n
		Snippet: value: float = driver.scan.custom.entry.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SCAN:CUSTom:ENTRy:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:SELect \n
		Snippet: driver.scan.custom.entry.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:SELect {param}')

	def get_trans_time(self) -> float:
		"""SCPI: SCAN:CUSTom:ENTRy:TRANstime \n
		Snippet: value: float = driver.scan.custom.entry.get_trans_time() \n
		Sets the time for the transition between two positions. \n
			:return: trans_time: float Range: 0 to 3600
		"""
		response = self._core.io.query_str('SCAN:CUSTom:ENTRy:TRANstime?')
		return Conversions.str_to_float(response)

	def set_trans_time(self, trans_time: float) -> None:
		"""SCPI: SCAN:CUSTom:ENTRy:TRANstime \n
		Snippet: driver.scan.custom.entry.set_trans_time(trans_time = 1.0) \n
		Sets the time for the transition between two positions. \n
			:param trans_time: float Range: 0 to 3600
		"""
		param = Conversions.decimal_value_to_str(trans_time)
		self._core.io.write(f'SCAN:CUSTom:ENTRy:TRANstime {param}')

	def clone(self) -> 'Entry':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Entry(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Normal:
	"""Normal commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("normal", core, parent)

	def get_limit(self) -> float:
		"""SCPI: IPM:RANDom:NORMal:LIMit \n
		Snippet: value: float = driver.ipm.random.normal.get_limit() \n
		Sets the limit parameter of the normal distribution function. \n
			:return: limit: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:RANDom:NORMal:LIMit?')
		return Conversions.str_to_float(response)

	def set_limit(self, limit: float) -> None:
		"""SCPI: IPM:RANDom:NORMal:LIMit \n
		Snippet: driver.ipm.random.normal.set_limit(limit = 1.0) \n
		Sets the limit parameter of the normal distribution function. \n
			:param limit: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(limit)
		self._core.io.write(f'IPM:RANDom:NORMal:LIMit {param}')

	def get_mean(self) -> float:
		"""SCPI: IPM:RANDom:NORMal:MEAN \n
		Snippet: value: float = driver.ipm.random.normal.get_mean() \n
		Sets the mean parameter of the normal distribution function. \n
			:return: mean: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:RANDom:NORMal:MEAN?')
		return Conversions.str_to_float(response)

	def set_mean(self, mean: float) -> None:
		"""SCPI: IPM:RANDom:NORMal:MEAN \n
		Snippet: driver.ipm.random.normal.set_mean(mean = 1.0) \n
		Sets the mean parameter of the normal distribution function. \n
			:param mean: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(mean)
		self._core.io.write(f'IPM:RANDom:NORMal:MEAN {param}')

	def get_std(self) -> float:
		"""SCPI: IPM:RANDom:NORMal:STD \n
		Snippet: value: float = driver.ipm.random.normal.get_std() \n
		Sets the standard deviation parameter of the normal distribution function. \n
			:return: std: float Range: 1e-09 to 1e+06
		"""
		response = self._core.io.query_str('IPM:RANDom:NORMal:STD?')
		return Conversions.str_to_float(response)

	def set_std(self, std: float) -> None:
		"""SCPI: IPM:RANDom:NORMal:STD \n
		Snippet: driver.ipm.random.normal.set_std(std = 1.0) \n
		Sets the standard deviation parameter of the normal distribution function. \n
			:param std: float Range: 1e-09 to 1e+06
		"""
		param = Conversions.decimal_value_to_str(std)
		self._core.io.write(f'IPM:RANDom:NORMal:STD {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Operation:
	"""Operation commands group definition. 5 total commands, 0 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("operation", core, parent)

	def get_condition(self) -> float:
		"""SCPI: STATus:OPERation:CONDition \n
		Snippet: value: float = driver.status.operation.get_condition() \n
		Queries the content of the CONDition part of the STATus:OPERation register. This part contains information on the action
		currently being performed in the instrument. The content is not deleted after being read out because it indicates the
		current status. \n
			:return: condition: float
		"""
		response = self._core.io.query_str('STATus:OPERation:CONDition?')
		return Conversions.str_to_float(response)

	def get_enable(self) -> bool:
		"""SCPI: STATus:OPERation:ENABle \n
		Snippet: value: bool = driver.status.operation.get_enable() \n
		No command help available \n
			:return: enable: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: STATus:OPERation:ENABle \n
		Snippet: driver.status.operation.set_enable(enable = False) \n
		No command help available \n
			:param enable: No help available
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'STATus:OPERation:ENABle {param}')

	def get_event(self) -> float:
		"""SCPI: STATus:OPERation:EVENt \n
		Snippet: value: float = driver.status.operation.get_event() \n
		No command help available \n
			:return: event: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:EVENt?')
		return Conversions.str_to_float(response)

	def get_ntransition(self) -> float:
		"""SCPI: STATus:OPERation:NTRansition \n
		Snippet: value: float = driver.status.operation.get_ntransition() \n
		No command help available \n
			:return: ntransition: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:NTRansition?')
		return Conversions.str_to_float(response)

	def set_ntransition(self, ntransition: float) -> None:
		"""SCPI: STATus:OPERation:NTRansition \n
		Snippet: driver.status.operation.set_ntransition(ntransition = 1.0) \n
		No command help available \n
			:param ntransition: No help available
		"""
		param = Conversions.decimal_value_to_str(ntransition)
		self._core.io.write(f'STATus:OPERation:NTRansition {param}')

	def get_ptransition(self) -> float:
		"""SCPI: STATus:OPERation:PTRansition \n
		Snippet: value: float = driver.status.operation.get_ptransition() \n
		No command help available \n
			:return: ptransition: No help available
		"""
		response = self._core.io.query_str('STATus:OPERation:PTRansition?')
		return Conversions.str_to_float(response)

	def set_ptransition(self, ptransition: float) -> None:
		"""SCPI: STATus:OPERation:PTRansition \n
		Snippet: driver.status.operation.set_ptransition(ptransition = 1.0) \n
		No command help available \n
			:param ptransition: No help available
		"""
		param = Conversions.decimal_value_to_str(ptransition)
		self._core.io.write(f'STATus:OPERation:PTRansition {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Receiver:
	"""Receiver commands group definition. 30 total commands, 2 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("receiver", core, parent)

	@property
	def direction(self):
		"""direction commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_direction'):
			from .Direction import Direction
			self._direction = Direction(self._core, self._cmd_group)
		return self._direction

	@property
	def movement(self):
		"""movement commands group. 4 Sub-classes, 17 commands."""
		if not hasattr(self, '_movement'):
			from .Movement import Movement
			self._movement = Movement(self._core, self._cmd_group)
		return self._movement

	def get_height(self) -> float:
		"""SCPI: SCENario:DF:RECeiver:HEIGht \n
		Snippet: value: float = driver.scenario.df.receiver.get_height() \n
		Sets the height of the antenna. \n
			:return: height: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('SCENario:DF:RECeiver:HEIGht?')
		return Conversions.str_to_float(response)

	def set_height(self, height: float) -> None:
		"""SCPI: SCENario:DF:RECeiver:HEIGht \n
		Snippet: driver.scenario.df.receiver.set_height(height = 1.0) \n
		Sets the height of the antenna. \n
			:param height: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(height)
		self._core.io.write(f'SCENario:DF:RECeiver:HEIGht {param}')

	def get_latitude(self) -> float:
		"""SCPI: SCENario:DF:RECeiver:LATitude \n
		Snippet: value: float = driver.scenario.df.receiver.get_latitude() \n
		Sets the latitude/longitude coordinates of the static receiver. \n
			:return: latitude: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:RECeiver:LATitude?')
		return Conversions.str_to_float(response)

	def set_latitude(self, latitude: float) -> None:
		"""SCPI: SCENario:DF:RECeiver:LATitude \n
		Snippet: driver.scenario.df.receiver.set_latitude(latitude = 1.0) \n
		Sets the latitude/longitude coordinates of the static receiver. \n
			:param latitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(latitude)
		self._core.io.write(f'SCENario:DF:RECeiver:LATitude {param}')

	def get_longitude(self) -> float:
		"""SCPI: SCENario:DF:RECeiver:LONGitude \n
		Snippet: value: float = driver.scenario.df.receiver.get_longitude() \n
		Sets the latitude/longitude coordinates of the static receiver. \n
			:return: longitude: float Range: -180 to 180
		"""
		response = self._core.io.query_str('SCENario:DF:RECeiver:LONGitude?')
		return Conversions.str_to_float(response)

	def set_longitude(self, longitude: float) -> None:
		"""SCPI: SCENario:DF:RECeiver:LONGitude \n
		Snippet: driver.scenario.df.receiver.set_longitude(longitude = 1.0) \n
		Sets the latitude/longitude coordinates of the static receiver. \n
			:param longitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(longitude)
		self._core.io.write(f'SCENario:DF:RECeiver:LONGitude {param}')

	def get_value(self) -> str:
		"""SCPI: SCENario:DF:RECeiver \n
		Snippet: value: str = driver.scenario.df.receiver.get_value() \n
		Selects an existing receiver, see method RsPulseSeq.Receiver.catalog. \n
			:return: receiver: string
		"""
		response = self._core.io.query_str('SCENario:DF:RECeiver?')
		return trim_str_response(response)

	def set_value(self, receiver: str) -> None:
		"""SCPI: SCENario:DF:RECeiver \n
		Snippet: driver.scenario.df.receiver.set_value(receiver = '1') \n
		Selects an existing receiver, see method RsPulseSeq.Receiver.catalog. \n
			:param receiver: string
		"""
		param = Conversions.value_to_quoted_str(receiver)
		self._core.io.write(f'SCENario:DF:RECeiver {param}')

	def clone(self) -> 'Receiver':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Receiver(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImportPy:
	"""ImportPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("importPy", core, parent)

	def set(self) -> None:
		"""SCPI: SCENario:LOCalized:RECeiver:MOVement:IMPort \n
		Snippet: driver.scenario.localized.receiver.movement.importPy.set() \n
		Imports the selected waypoint and vehicle description files into the repository and applies them. \n
		"""
		self._core.io.write(f'SCENario:LOCalized:RECeiver:MOVement:IMPort')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:LOCalized:RECeiver:MOVement:IMPort \n
		Snippet: driver.scenario.localized.receiver.movement.importPy.set_with_opc() \n
		Imports the selected waypoint and vehicle description files into the repository and applies them. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:LOCalized:RECeiver:MOVement:IMPort', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cardoid:
	"""Cardoid commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cardoid", core, parent)

	def get_exponent(self) -> float:
		"""SCPI: ANTenna:MODel:CARDoid:EXPonent \n
		Snippet: value: float = driver.antenna.model.cardoid.get_exponent() \n
		Use values greater than 1 to narrow the antenna beam. \n
			:return: exponent: float Range: 1 to 20
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARDoid:EXPonent?')
		return Conversions.str_to_float(response)

	def set_exponent(self, exponent: float) -> None:
		"""SCPI: ANTenna:MODel:CARDoid:EXPonent \n
		Snippet: driver.antenna.model.cardoid.set_exponent(exponent = 1.0) \n
		Use values greater than 1 to narrow the antenna beam. \n
			:param exponent: float Range: 1 to 20
		"""
		param = Conversions.decimal_value_to_str(exponent)
		self._core.io.write(f'ANTenna:MODel:CARDoid:EXPonent {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Prbs:
	"""Prbs commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("prbs", core, parent)

	@property
	def init(self):
		"""init commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_init'):
			from .Init import Init
			self._init = Init(self._core, self._cmd_group)
		return self._init

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.PrbsType:
		"""SCPI: DSRC:ITEM:PRBS:TYPE \n
		Snippet: value: enums.PrbsType = driver.dsrc.item.prbs.get_type_py() \n
		Sets the PRBS type for the selected item. \n
			:return: type_py: P9| P11| P15| P16| P20| P21| P23| P7
		"""
		response = self._core.io.query_str('DSRC:ITEM:PRBS:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.PrbsType)

	def set_type_py(self, type_py: enums.PrbsType) -> None:
		"""SCPI: DSRC:ITEM:PRBS:TYPE \n
		Snippet: driver.dsrc.item.prbs.set_type_py(type_py = enums.PrbsType.P11) \n
		Sets the PRBS type for the selected item. \n
			:param type_py: P9| P11| P15| P16| P20| P21| P23| P7
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.PrbsType)
		self._core.io.write(f'DSRC:ITEM:PRBS:TYPE {param}')

	def clone(self) -> 'Prbs':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Prbs(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Qpsk:
	"""Qpsk commands group definition. 3 total commands, 1 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("qpsk", core, parent)

	@property
	def soQpsk(self):
		"""soQpsk commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_soQpsk'):
			from .SoQpsk import SoQpsk
			self._soQpsk = SoQpsk(self._core, self._cmd_group)
		return self._soQpsk

	def get_symbol_rate(self) -> float:
		"""SCPI: PULSe:MOP:QPSK:SRATe \n
		Snippet: value: float = driver.pulse.mop.qpsk.get_symbol_rate() \n
		Sets the symbol rate. \n
			:return: srate: float Range: 1 to 1e+09
		"""
		response = self._core.io.query_str('PULSe:MOP:QPSK:SRATe?')
		return Conversions.str_to_float(response)

	def set_symbol_rate(self, srate: float) -> None:
		"""SCPI: PULSe:MOP:QPSK:SRATe \n
		Snippet: driver.pulse.mop.qpsk.set_symbol_rate(srate = 1.0) \n
		Sets the symbol rate. \n
			:param srate: float Range: 1 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(srate)
		self._core.io.write(f'PULSe:MOP:QPSK:SRATe {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.QpskType:
		"""SCPI: PULSe:MOP:QPSK:TYPE \n
		Snippet: value: enums.QpskType = driver.pulse.mop.qpsk.get_type_py() \n
		Selects the modulation type. \n
			:return: type_py: NORMal| OQPSk| DQPSk| ASOQpsk| BSOQpsk| TGSoqpsk
		"""
		response = self._core.io.query_str('PULSe:MOP:QPSK:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.QpskType)

	def set_type_py(self, type_py: enums.QpskType) -> None:
		"""SCPI: PULSe:MOP:QPSK:TYPE \n
		Snippet: driver.pulse.mop.qpsk.set_type_py(type_py = enums.QpskType.ASOQpsk) \n
		Selects the modulation type. \n
			:param type_py: NORMal| OQPSk| DQPSk| ASOQpsk| BSOQpsk| TGSoqpsk
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.QpskType)
		self._core.io.write(f'PULSe:MOP:QPSK:TYPE {param}')

	def clone(self) -> 'Qpsk':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Qpsk(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Repmanager:
	"""Repmanager commands group definition. 7 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("repmanager", core, parent)

	@property
	def path(self):
		"""path commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_path'):
			from .Path import Path
			self._path = Path(self._core, self._cmd_group)
		return self._path

	def get_catalog(self) -> List[int]:
		"""SCPI: REPManager:CATalog \n
		Snippet: value: List[int] = driver.repmanager.get_catalog() \n
		Queries available repository elements in the database. \n
			:return: catalog: 'RepositryName','path' RepositryName is the name of the repository as defined with the command method RsPulseSeq.Repository.create Path is the compete file path
		"""
		response = self._core.io.query_bin_or_ascii_int_list('REPManager:CATalog?')
		return response

	def delete(self, delete: List[int]) -> None:
		"""SCPI: REPManager:DELete \n
		Snippet: driver.repmanager.delete(delete = [1, 2, 3]) \n
		Deletes the entire repository from the permanent mass storage. \n
			:param delete: No help available
		"""
		param = Conversions.list_to_csv_str(delete)
		self._core.io.write(f'REPManager:DELete {param}')

	def export(self, export: List[int]) -> None:
		"""SCPI: REPManager:EXPort \n
		Snippet: driver.repmanager.export(export = [1, 2, 3]) \n
		Exports the selected repository file to an archive file. \n
			:param export: No help available
		"""
		param = Conversions.list_to_csv_str(export)
		self._core.io.write(f'REPManager:EXPort {param}')

	def load(self, load: List[int]) -> None:
		"""SCPI: REPManager:LOAD \n
		Snippet: driver.repmanager.load(load = [1, 2, 3]) \n
		Loads the selected repository to the workspace. If more than one repository with the same name exist, loaded is the first
		repository with a name match. To query the available repository elements in the database, use the command method
		RsPulseSeq.Repository.catalog. \n
			:param load: No help available
		"""
		param = Conversions.list_to_csv_str(load)
		self._core.io.write(f'REPManager:LOAD {param}')

	def clone(self) -> 'Repmanager':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Repmanager(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 6 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("file", core, parent)

	@property
	def pdw(self):
		"""pdw commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_pdw'):
			from .Pdw import Pdw
			self._pdw = Pdw(self._core, self._cmd_group)
		return self._pdw

	@property
	def template(self):
		"""template commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_template'):
			from .Template import Template
			self._template = Template(self._core, self._cmd_group)
		return self._template

	def clone(self) -> 'File':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = File(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Generator:
	"""Generator commands group definition. 15 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("generator", core, parent)

	@property
	def path(self):
		"""path commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_path'):
			from .Path import Path
			self._path = Path(self._core, self._cmd_group)
		return self._path

	def get_capabilities(self) -> str:
		"""SCPI: ASSignment:GENerator:CAPabilities \n
		Snippet: value: str = driver.assignment.generator.get_capabilities() \n
		Queries the capabilities of the selected generator. \n
			:return: capabilities: RFA, BWA, MEMA, SWA, [RFB, BWB, MEMB, SWB] String that lists the maximum RF and BW, available memory size, and installed options per path.
		"""
		response = self._core.io.query_str('ASSignment:GENerator:CAPabilities?')
		return trim_str_response(response)

	def get_list_py(self) -> str:
		"""SCPI: ASSignment:GENerator:LIST \n
		Snippet: value: str = driver.assignment.generator.get_list_py() \n
		Queries a list of the available generators. \n
			:return: list_py: 'GenName#1','GenName2',...
		"""
		response = self._core.io.query_str('ASSignment:GENerator:LIST?')
		return trim_str_response(response)

	def get_select(self) -> str:
		"""SCPI: ASSignment:GENerator:SELect \n
		Snippet: value: str = driver.assignment.generator.get_select() \n
		Selects the element to which the subsequent commands apply. \n
			:return: select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		response = self._core.io.query_str('ASSignment:GENerator:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: ASSignment:GENerator:SELect \n
		Snippet: driver.assignment.generator.set_select(select = '1') \n
		Selects the element to which the subsequent commands apply. \n
			:param select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'ASSignment:GENerator:SELect {param}')

	def clone(self) -> 'Generator':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Generator(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Utime:
	"""Utime commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("utime", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SCENario:PDW:AMMos:UTIMe:ENABle \n
		Snippet: value: bool = driver.scenario.pdw.amMos.utime.get_enable() \n
		Defines how the report start time is set. \n
			:return: enable: ON| OFF| 1| 0 0 The reporting start time is time at that the scenario calculation starts. 1 The reporting starts at user-defined moment, set with the command method RsPulseSeq.Scenario.Pdw.AmMos.Utime.iso.
		"""
		response = self._core.io.query_str('SCENario:PDW:AMMos:UTIMe:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SCENario:PDW:AMMos:UTIMe:ENABle \n
		Snippet: driver.scenario.pdw.amMos.utime.set_enable(enable = False) \n
		Defines how the report start time is set. \n
			:param enable: ON| OFF| 1| 0 0 The reporting start time is time at that the scenario calculation starts. 1 The reporting starts at user-defined moment, set with the command method RsPulseSeq.Scenario.Pdw.AmMos.Utime.iso.
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:PDW:AMMos:UTIMe:ENABle {param}')

	def get_iso(self) -> str:
		"""SCPI: SCENario:PDW:AMMos:UTIMe:ISO \n
		Snippet: value: str = driver.scenario.pdw.amMos.utime.get_iso() \n
		Sets the reporting start time, if method RsPulseSeq.Scenario.Pdw.AmMos.Utime.enable1. \n
			:return: iso: 'YYYY-Month-DDTHH:MM:SS'
		"""
		response = self._core.io.query_str('SCENario:PDW:AMMos:UTIMe:ISO?')
		return trim_str_response(response)

	def set_iso(self, iso: str) -> None:
		"""SCPI: SCENario:PDW:AMMos:UTIMe:ISO \n
		Snippet: driver.scenario.pdw.amMos.utime.set_iso(iso = '1') \n
		Sets the reporting start time, if method RsPulseSeq.Scenario.Pdw.AmMos.Utime.enable1. \n
			:param iso: 'YYYY-Month-DDTHH:MM:SS'
		"""
		param = Conversions.value_to_quoted_str(iso)
		self._core.io.write(f'SCENario:PDW:AMMos:UTIMe:ISO {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spiral:
	"""Spiral commands group definition. 9 total commands, 0 Subgroups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spiral", core, parent)

	def get_palmer(self) -> bool:
		"""SCPI: SCAN:SPIRal:PALMer \n
		Snippet: value: bool = driver.scan.spiral.get_palmer() \n
		Enables superimposing a conical scan on the current scan. \n
			:return: palmer: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:SPIRal:PALMer?')
		return Conversions.str_to_bool(response)

	def set_palmer(self, palmer: bool) -> None:
		"""SCPI: SCAN:SPIRal:PALMer \n
		Snippet: driver.scan.spiral.set_palmer(palmer = False) \n
		Enables superimposing a conical scan on the current scan. \n
			:param palmer: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(palmer)
		self._core.io.write(f'SCAN:SPIRal:PALMer {param}')

	def get_prate(self) -> float:
		"""SCPI: SCAN:SPIRal:PRATe \n
		Snippet: value: float = driver.scan.spiral.get_prate() \n
		Sets the scan rate. \n
			:return: prate: float Range: 0.1 to 1000
		"""
		response = self._core.io.query_str('SCAN:SPIRal:PRATe?')
		return Conversions.str_to_float(response)

	def set_prate(self, prate: float) -> None:
		"""SCPI: SCAN:SPIRal:PRATe \n
		Snippet: driver.scan.spiral.set_prate(prate = 1.0) \n
		Sets the scan rate. \n
			:param prate: float Range: 0.1 to 1000
		"""
		param = Conversions.decimal_value_to_str(prate)
		self._core.io.write(f'SCAN:SPIRal:PRATe {param}')

	def get_psquint(self) -> float:
		"""SCPI: SCAN:SPIRal:PSQuint \n
		Snippet: value: float = driver.scan.spiral.get_psquint() \n
		Sets the squint angle. \n
			:return: psquint: float Range: 0.05 to 45
		"""
		response = self._core.io.query_str('SCAN:SPIRal:PSQuint?')
		return Conversions.str_to_float(response)

	def set_psquint(self, psquint: float) -> None:
		"""SCPI: SCAN:SPIRal:PSQuint \n
		Snippet: driver.scan.spiral.set_psquint(psquint = 1.0) \n
		Sets the squint angle. \n
			:param psquint: float Range: 0.05 to 45
		"""
		param = Conversions.decimal_value_to_str(psquint)
		self._core.io.write(f'SCAN:SPIRal:PSQuint {param}')

	def get_retrace(self) -> float:
		"""SCPI: SCAN:SPIRal:RETRace \n
		Snippet: value: float = driver.scan.spiral.get_retrace() \n
		Sets the speed for the antenna to return to the initial orientation. \n
			:return: retrace: float Range: 0 to 1
		"""
		response = self._core.io.query_str('SCAN:SPIRal:RETRace?')
		return Conversions.str_to_float(response)

	def set_retrace(self, retrace: float) -> None:
		"""SCPI: SCAN:SPIRal:RETRace \n
		Snippet: driver.scan.spiral.set_retrace(retrace = 1.0) \n
		Sets the speed for the antenna to return to the initial orientation. \n
			:param retrace: float Range: 0 to 1
		"""
		param = Conversions.decimal_value_to_str(retrace)
		self._core.io.write(f'SCAN:SPIRal:RETRace {param}')

	# noinspection PyTypeChecker
	def get_rotation(self) -> enums.Rotation:
		"""SCPI: SCAN:SPIRal:ROTation \n
		Snippet: value: enums.Rotation = driver.scan.spiral.get_rotation() \n
		Sets the rotation direction of the antenna. \n
			:return: rotation: CW| CCW
		"""
		response = self._core.io.query_str('SCAN:SPIRal:ROTation?')
		return Conversions.str_to_scalar_enum(response, enums.Rotation)

	def set_rotation(self, rotation: enums.Rotation) -> None:
		"""SCPI: SCAN:SPIRal:ROTation \n
		Snippet: driver.scan.spiral.set_rotation(rotation = enums.Rotation.CCW) \n
		Sets the rotation direction of the antenna. \n
			:param rotation: CW| CCW
		"""
		param = Conversions.enum_scalar_to_str(rotation, enums.Rotation)
		self._core.io.write(f'SCAN:SPIRal:ROTation {param}')

	def get_rounds(self) -> float:
		"""SCPI: SCAN:SPIRal:ROUNds \n
		Snippet: value: float = driver.scan.spiral.get_rounds() \n
		Sets the number of rounds the antenna performs. \n
			:return: rounds: float Range: 0.1 to 15
		"""
		response = self._core.io.query_str('SCAN:SPIRal:ROUNds?')
		return Conversions.str_to_float(response)

	def set_rounds(self, rounds: float) -> None:
		"""SCPI: SCAN:SPIRal:ROUNds \n
		Snippet: driver.scan.spiral.set_rounds(rounds = 1.0) \n
		Sets the number of rounds the antenna performs. \n
			:param rounds: float Range: 0.1 to 15
		"""
		param = Conversions.decimal_value_to_str(rounds)
		self._core.io.write(f'SCAN:SPIRal:ROUNds {param}')

	def get_rtime(self) -> float:
		"""SCPI: SCAN:SPIRal:RTIMe \n
		Snippet: value: float = driver.scan.spiral.get_rtime() \n
		Sets the turning speed of the antenna. \n
			:return: rtime: float Range: 0.01 to 10, Unit: degree/s
		"""
		response = self._core.io.query_str('SCAN:SPIRal:RTIMe?')
		return Conversions.str_to_float(response)

	def set_rtime(self, rtime: float) -> None:
		"""SCPI: SCAN:SPIRal:RTIMe \n
		Snippet: driver.scan.spiral.set_rtime(rtime = 1.0) \n
		Sets the turning speed of the antenna. \n
			:param rtime: float Range: 0.01 to 10, Unit: degree/s
		"""
		param = Conversions.decimal_value_to_str(rtime)
		self._core.io.write(f'SCAN:SPIRal:RTIMe {param}')

	def get_step(self) -> float:
		"""SCPI: SCAN:SPIRal:STEP \n
		Snippet: value: float = driver.scan.spiral.get_step() \n
		Determines the step size to increase the scan radius. \n
			:return: step: float Range: 1 to 11.25, Unit: degree
		"""
		response = self._core.io.query_str('SCAN:SPIRal:STEP?')
		return Conversions.str_to_float(response)

	def set_step(self, step: float) -> None:
		"""SCPI: SCAN:SPIRal:STEP \n
		Snippet: driver.scan.spiral.set_step(step = 1.0) \n
		Determines the step size to increase the scan radius. \n
			:param step: float Range: 1 to 11.25, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(step)
		self._core.io.write(f'SCAN:SPIRal:STEP {param}')

	def get_uni_direction(self) -> bool:
		"""SCPI: SCAN:SPIRal:UNIDirection \n
		Snippet: value: bool = driver.scan.spiral.get_uni_direction() \n
		Enables a unidirectional scan mode. \n
			:return: uni_direction: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCAN:SPIRal:UNIDirection?')
		return Conversions.str_to_bool(response)

	def set_uni_direction(self, uni_direction: bool) -> None:
		"""SCPI: SCAN:SPIRal:UNIDirection \n
		Snippet: driver.scan.spiral.set_uni_direction(uni_direction = False) \n
		Enables a unidirectional scan mode. \n
			:param uni_direction: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(uni_direction)
		self._core.io.write(f'SCAN:SPIRal:UNIDirection {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Df:
	"""Df commands group definition. 143 total commands, 14 Subgroups, 14 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("df", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	@property
	def direction(self):
		"""direction commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_direction'):
			from .Direction import Direction
			self._direction = Direction(self._core, self._cmd_group)
		return self._direction

	@property
	def emitter(self):
		"""emitter commands group. 2 Sub-classes, 2 commands."""
		if not hasattr(self, '_emitter'):
			from .Emitter import Emitter
			self._emitter = Emitter(self._core, self._cmd_group)
		return self._emitter

	@property
	def group(self):
		"""group commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_group'):
			from .Group import Group
			self._group = Group(self._core, self._cmd_group)
		return self._group

	@property
	def interleaving(self):
		"""interleaving commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_interleaving'):
			from .Interleaving import Interleaving
			self._interleaving = Interleaving(self._core, self._cmd_group)
		return self._interleaving

	@property
	def location(self):
		"""location commands group. 3 Sub-classes, 9 commands."""
		if not hasattr(self, '_location'):
			from .Location import Location
			self._location = Location(self._core, self._cmd_group)
		return self._location

	@property
	def maps(self):
		"""maps commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_maps'):
			from .Maps import Maps
			self._maps = Maps(self._core, self._cmd_group)
		return self._maps

	@property
	def marker(self):
		"""marker commands group. 1 Sub-classes, 8 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import Marker
			self._marker = Marker(self._core, self._cmd_group)
		return self._marker

	@property
	def mchg(self):
		"""mchg commands group. 1 Sub-classes, 7 commands."""
		if not hasattr(self, '_mchg'):
			from .Mchg import Mchg
			self._mchg = Mchg(self._core, self._cmd_group)
		return self._mchg

	@property
	def movement(self):
		"""movement commands group. 2 Sub-classes, 23 commands."""
		if not hasattr(self, '_movement'):
			from .Movement import Movement
			self._movement = Movement(self._core, self._cmd_group)
		return self._movement

	@property
	def receiver(self):
		"""receiver commands group. 2 Sub-classes, 4 commands."""
		if not hasattr(self, '_receiver'):
			from .Receiver import Receiver
			self._receiver = Receiver(self._core, self._cmd_group)
		return self._receiver

	@property
	def subitem(self):
		"""subitem commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_subitem'):
			from .Subitem import Subitem
			self._subitem = Subitem(self._core, self._cmd_group)
		return self._subitem

	@property
	def synchronize(self):
		"""synchronize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_synchronize'):
			from .Synchronize import Synchronize
			self._synchronize = Synchronize(self._core, self._cmd_group)
		return self._synchronize

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 6 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import Waveform
			self._waveform = Waveform(self._core, self._cmd_group)
		return self._waveform

	def get_alias(self) -> str:
		"""SCPI: SCENario:DF:ALIas \n
		Snippet: value: str = driver.scenario.df.get_alias() \n
		Enters an alias name. \n
			:return: alias: string
		"""
		response = self._core.io.query_str('SCENario:DF:ALIas?')
		return trim_str_response(response)

	def set_alias(self, alias: str) -> None:
		"""SCPI: SCENario:DF:ALIas \n
		Snippet: driver.scenario.df.set_alias(alias = '1') \n
		Enters an alias name. \n
			:param alias: string
		"""
		param = Conversions.value_to_quoted_str(alias)
		self._core.io.write(f'SCENario:DF:ALIas {param}')

	def clear(self) -> None:
		"""SCPI: SCENario:DF:CLEar \n
		Snippet: driver.scenario.df.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'SCENario:DF:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:DF:CLEar \n
		Snippet: driver.scenario.df.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:DF:CLEar', opc_timeout_ms)

	def get_current(self) -> float:
		"""SCPI: SCENario:DF:CURRent \n
		Snippet: value: float = driver.scenario.df.get_current() \n
		Sets the sequence/emitter that is used by the scenario. \n
			:return: current: float Number of the sequence/emitter in the list with multiple sequences
		"""
		response = self._core.io.query_str('SCENario:DF:CURRent?')
		return Conversions.str_to_float(response)

	def set_current(self, current: float) -> None:
		"""SCPI: SCENario:DF:CURRent \n
		Snippet: driver.scenario.df.set_current(current = 1.0) \n
		Sets the sequence/emitter that is used by the scenario. \n
			:param current: float Number of the sequence/emitter in the list with multiple sequences
		"""
		param = Conversions.decimal_value_to_str(current)
		self._core.io.write(f'SCENario:DF:CURRent {param}')

	def delete(self, delete: float) -> None:
		"""SCPI: SCENario:DF:DELete \n
		Snippet: driver.scenario.df.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SCENario:DF:DELete {param}')

	def get_distance(self) -> float:
		"""SCPI: SCENario:DF:DISTance \n
		Snippet: value: float = driver.scenario.df.get_distance() \n
		Sets the distance to the receiver. \n
			:return: distance: float Range: 0 to 1e+09, Unit: m
		"""
		response = self._core.io.query_str('SCENario:DF:DISTance?')
		return Conversions.str_to_float(response)

	def set_distance(self, distance: float) -> None:
		"""SCPI: SCENario:DF:DISTance \n
		Snippet: driver.scenario.df.set_distance(distance = 1.0) \n
		Sets the distance to the receiver. \n
			:param distance: float Range: 0 to 1e+09, Unit: m
		"""
		param = Conversions.decimal_value_to_str(distance)
		self._core.io.write(f'SCENario:DF:DISTance {param}')

	def get_enable(self) -> bool:
		"""SCPI: SCENario:DF:ENABle \n
		Snippet: value: bool = driver.scenario.df.get_enable() \n
		If enabled, the PDW list is included in the output file. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:DF:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SCENario:DF:ENABle \n
		Snippet: driver.scenario.df.set_enable(enable = False) \n
		If enabled, the PDW list is included in the output file. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:DF:ENABle {param}')

	def get_frequency(self) -> float:
		"""SCPI: SCENario:DF:FREQuency \n
		Snippet: value: float = driver.scenario.df.get_frequency() \n
		Sets the frequency for the selected emitter. \n
			:return: frequency: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:FREQuency?')
		return Conversions.str_to_float(response)

	def get_ldelay(self) -> float:
		"""SCPI: SCENario:DF:LDELay \n
		Snippet: value: float = driver.scenario.df.get_ldelay() \n
		If interleaving is enabled, shifts the processing of the selected PDW list in time. \n
			:return: ldelay: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('SCENario:DF:LDELay?')
		return Conversions.str_to_float(response)

	def set_ldelay(self, ldelay: float) -> None:
		"""SCPI: SCENario:DF:LDELay \n
		Snippet: driver.scenario.df.set_ldelay(ldelay = 1.0) \n
		If interleaving is enabled, shifts the processing of the selected PDW list in time. \n
			:param ldelay: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(ldelay)
		self._core.io.write(f'SCENario:DF:LDELay {param}')

	def get_level(self) -> float:
		"""SCPI: SCENario:DF:LEVel \n
		Snippet: value: float = driver.scenario.df.get_level() \n
		Adds a level offset. \n
			:return: level: float Range: -200 to 0
		"""
		response = self._core.io.query_str('SCENario:DF:LEVel?')
		return Conversions.str_to_float(response)

	def set_level(self, level: float) -> None:
		"""SCPI: SCENario:DF:LEVel \n
		Snippet: driver.scenario.df.set_level(level = 1.0) \n
		Adds a level offset. \n
			:param level: float Range: -200 to 0
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'SCENario:DF:LEVel {param}')

	def get_priority(self) -> float:
		"""SCPI: SCENario:DF:PRIority \n
		Snippet: value: float = driver.scenario.df.get_priority() \n
		Sets the priority of the selected PDW list , where the higher the value the higher the priority. \n
			:return: priority: float Range: 1 to 100
		"""
		response = self._core.io.query_str('SCENario:DF:PRIority?')
		return Conversions.str_to_float(response)

	def set_priority(self, priority: float) -> None:
		"""SCPI: SCENario:DF:PRIority \n
		Snippet: driver.scenario.df.set_priority(priority = 1.0) \n
		Sets the priority of the selected PDW list , where the higher the value the higher the priority. \n
			:param priority: float Range: 1 to 100
		"""
		param = Conversions.decimal_value_to_str(priority)
		self._core.io.write(f'SCENario:DF:PRIority {param}')

	def get_select(self) -> float:
		"""SCPI: SCENario:DF:SELect \n
		Snippet: value: float = driver.scenario.df.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SCENario:DF:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SCENario:DF:SELect \n
		Snippet: driver.scenario.df.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SCENario:DF:SELect {param}')

	def get_sequence(self) -> str:
		"""SCPI: SCENario:DF:SEQuence \n
		Snippet: value: str = driver.scenario.df.get_sequence() \n
		Assigns a sequence to the background signal. \n
			:return: sequence: string
		"""
		response = self._core.io.query_str('SCENario:DF:SEQuence?')
		return trim_str_response(response)

	def set_sequence(self, sequence: str) -> None:
		"""SCPI: SCENario:DF:SEQuence \n
		Snippet: driver.scenario.df.set_sequence(sequence = '1') \n
		Assigns a sequence to the background signal. \n
			:param sequence: string
		"""
		param = Conversions.value_to_quoted_str(sequence)
		self._core.io.write(f'SCENario:DF:SEQuence {param}')

	def get_threshold(self) -> float:
		"""SCPI: SCENario:DF:THReshold \n
		Snippet: value: float = driver.scenario.df.get_threshold() \n
		Sets a threshold. Pulses at levels below this threshold are omitted. \n
			:return: threshold: float Range: -100 to 0
		"""
		response = self._core.io.query_str('SCENario:DF:THReshold?')
		return Conversions.str_to_float(response)

	def set_threshold(self, threshold: float) -> None:
		"""SCPI: SCENario:DF:THReshold \n
		Snippet: driver.scenario.df.set_threshold(threshold = 1.0) \n
		Sets a threshold. Pulses at levels below this threshold are omitted. \n
			:param threshold: float Range: -100 to 0
		"""
		param = Conversions.decimal_value_to_str(threshold)
		self._core.io.write(f'SCENario:DF:THReshold {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.DfType:
		"""SCPI: SCENario:DF:TYPE \n
		Snippet: value: enums.DfType = driver.scenario.df.get_type_py() \n
		Defines whether an emitter/interferer is configured. \n
			:return: type_py: EMITter | | WAVeform
		"""
		response = self._core.io.query_str('SCENario:DF:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.DfType)

	def set_type_py(self, type_py: enums.DfType) -> None:
		"""SCPI: SCENario:DF:TYPE \n
		Snippet: driver.scenario.df.set_type_py(type_py = enums.DfType.BACKground) \n
		Defines whether an emitter/interferer is configured. \n
			:param type_py: EMITter | | WAVeform
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.DfType)
		self._core.io.write(f'SCENario:DF:TYPE {param}')

	def clone(self) -> 'Df':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Df(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Movement:
	"""Movement commands group definition. 26 total commands, 2 Subgroups, 23 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("movement", core, parent)

	@property
	def importPy(self):
		"""importPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_importPy'):
			from .ImportPy import ImportPy
			self._importPy = ImportPy(self._core, self._cmd_group)
		return self._importPy

	@property
	def vfile(self):
		"""vfile commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_vfile'):
			from .Vfile import Vfile
			self._vfile = Vfile(self._core, self._cmd_group)
		return self._vfile

	def get_acceleration(self) -> float:
		"""SCPI: SCENario:DF:MOVement:ACCeleration \n
		Snippet: value: float = driver.scenario.df.movement.get_acceleration() \n
		Sets the acceleration of the moving emitter. \n
			:return: acceleration: float Range: -100 to 100
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:ACCeleration?')
		return Conversions.str_to_float(response)

	def set_acceleration(self, acceleration: float) -> None:
		"""SCPI: SCENario:DF:MOVement:ACCeleration \n
		Snippet: driver.scenario.df.movement.set_acceleration(acceleration = 1.0) \n
		Sets the acceleration of the moving emitter. \n
			:param acceleration: float Range: -100 to 100
		"""
		param = Conversions.decimal_value_to_str(acceleration)
		self._core.io.write(f'SCENario:DF:MOVement:ACCeleration {param}')

	def get_altitude(self) -> float:
		"""SCPI: SCENario:DF:MOVement:ALTitude \n
		Snippet: value: float = driver.scenario.df.movement.get_altitude() \n
		Use for defining the altitude of a moving emitter (line trajectory) on a georeferenced map. Use to define the altitude of
		the end-points of the line. \n
			:return: altitude: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:ALTitude?')
		return Conversions.str_to_float(response)

	def set_altitude(self, altitude: float) -> None:
		"""SCPI: SCENario:DF:MOVement:ALTitude \n
		Snippet: driver.scenario.df.movement.set_altitude(altitude = 1.0) \n
		Use for defining the altitude of a moving emitter (line trajectory) on a georeferenced map. Use to define the altitude of
		the end-points of the line. \n
			:param altitude: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(altitude)
		self._core.io.write(f'SCENario:DF:MOVement:ALTitude {param}')

	def get_angle(self) -> float:
		"""SCPI: SCENario:DF:MOVement:ANGLe \n
		Snippet: value: float = driver.scenario.df.movement.get_angle() \n
		Sets the arc angle and thus defines the arc length. \n
			:return: angle: float Range: -360 to 360
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:ANGLe?')
		return Conversions.str_to_float(response)

	def set_angle(self, angle: float) -> None:
		"""SCPI: SCENario:DF:MOVement:ANGLe \n
		Snippet: driver.scenario.df.movement.set_angle(angle = 1.0) \n
		Sets the arc angle and thus defines the arc length. \n
			:param angle: float Range: -360 to 360
		"""
		param = Conversions.decimal_value_to_str(angle)
		self._core.io.write(f'SCENario:DF:MOVement:ANGLe {param}')

	# noinspection PyTypeChecker
	def get_attitude(self) -> enums.Attitude:
		"""SCPI: SCENario:DF:MOVement:ATTitude \n
		Snippet: value: enums.Attitude = driver.scenario.df.movement.get_attitude() \n
		Defines how the attitude information is defined. \n
			:return: attitude: WAYPoint| MOTion| CONStant WAYPoint The attitude parameters are extracted from the selected waypoint file. MOTion Enables a constant rate of change of the roll. See method RsPulseSeq.Scenario.Localized.Movement.roll Constant The attitude is constant values.
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:ATTitude?')
		return Conversions.str_to_scalar_enum(response, enums.Attitude)

	def set_attitude(self, attitude: enums.Attitude) -> None:
		"""SCPI: SCENario:DF:MOVement:ATTitude \n
		Snippet: driver.scenario.df.movement.set_attitude(attitude = enums.Attitude.CONStant) \n
		Defines how the attitude information is defined. \n
			:param attitude: WAYPoint| MOTion| CONStant WAYPoint The attitude parameters are extracted from the selected waypoint file. MOTion Enables a constant rate of change of the roll. See method RsPulseSeq.Scenario.Localized.Movement.roll Constant The attitude is constant values.
		"""
		param = Conversions.enum_scalar_to_str(attitude, enums.Attitude)
		self._core.io.write(f'SCENario:DF:MOVement:ATTitude {param}')

	def get_clatitude(self) -> float:
		"""SCPI: SCENario:DF:MOVement:CLATitude \n
		Snippet: value: float = driver.scenario.df.movement.get_clatitude() \n
		Use for defining the movement of an emitter (arc trajectory) on a georeferenced map. Use to define the center-point of
		the arc. Positive values represent °East. Negative values represent °West. \n
			:return: clatitude: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:CLATitude?')
		return Conversions.str_to_float(response)

	def set_clatitude(self, clatitude: float) -> None:
		"""SCPI: SCENario:DF:MOVement:CLATitude \n
		Snippet: driver.scenario.df.movement.set_clatitude(clatitude = 1.0) \n
		Use for defining the movement of an emitter (arc trajectory) on a georeferenced map. Use to define the center-point of
		the arc. Positive values represent °East. Negative values represent °West. \n
			:param clatitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(clatitude)
		self._core.io.write(f'SCENario:DF:MOVement:CLATitude {param}')

	def clear(self) -> None:
		"""SCPI: SCENario:DF:MOVement:CLEar \n
		Snippet: driver.scenario.df.movement.clear() \n
		Discards the waypoint and vehicle description file. \n
		"""
		self._core.io.write(f'SCENario:DF:MOVement:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:DF:MOVement:CLEar \n
		Snippet: driver.scenario.df.movement.clear_with_opc() \n
		Discards the waypoint and vehicle description file. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:DF:MOVement:CLEar', opc_timeout_ms)

	def get_clongitude(self) -> float:
		"""SCPI: SCENario:DF:MOVement:CLONgitude \n
		Snippet: value: float = driver.scenario.df.movement.get_clongitude() \n
		Use for defining the movement of an emitter (arc trajectory) on a georeferenced map. Use to define the center-point of
		the arc. Positive values represent °East. Negative values represent °West. \n
			:return: clongitude: float Range: -180 to 180
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:CLONgitude?')
		return Conversions.str_to_float(response)

	def set_clongitude(self, clongitude: float) -> None:
		"""SCPI: SCENario:DF:MOVement:CLONgitude \n
		Snippet: driver.scenario.df.movement.set_clongitude(clongitude = 1.0) \n
		Use for defining the movement of an emitter (arc trajectory) on a georeferenced map. Use to define the center-point of
		the arc. Positive values represent °East. Negative values represent °West. \n
			:param clongitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(clongitude)
		self._core.io.write(f'SCENario:DF:MOVement:CLONgitude {param}')

	def get_east(self) -> float:
		"""SCPI: SCENario:DF:MOVement:EAST \n
		Snippet: value: float = driver.scenario.df.movement.get_east() \n
		Sets the East/North coordinates of the emitter at the end of the movement. \n
			:return: east: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:EAST?')
		return Conversions.str_to_float(response)

	def set_east(self, east: float) -> None:
		"""SCPI: SCENario:DF:MOVement:EAST \n
		Snippet: driver.scenario.df.movement.set_east(east = 1.0) \n
		Sets the East/North coordinates of the emitter at the end of the movement. \n
			:param east: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(east)
		self._core.io.write(f'SCENario:DF:MOVement:EAST {param}')

	def get_height(self) -> float:
		"""SCPI: SCENario:DF:MOVement:HEIGht \n
		Snippet: value: float = driver.scenario.df.movement.get_height() \n
		Sets the height of the emitter at the end of the movement. \n
			:return: height: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:HEIGht?')
		return Conversions.str_to_float(response)

	def set_height(self, height: float) -> None:
		"""SCPI: SCENario:DF:MOVement:HEIGht \n
		Snippet: driver.scenario.df.movement.set_height(height = 1.0) \n
		Sets the height of the emitter at the end of the movement. \n
			:param height: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(height)
		self._core.io.write(f'SCENario:DF:MOVement:HEIGht {param}')

	def get_latitude(self) -> float:
		"""SCPI: SCENario:DF:MOVement:LATitude \n
		Snippet: value: float = driver.scenario.df.movement.get_latitude() \n
		Use for defining the movement of an emitter (line trajectory) on a georeferenced map. Use to define the end-points of the
		line. Positive values represent °East. Negative values represent °West. \n
			:return: latitude: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:LATitude?')
		return Conversions.str_to_float(response)

	def set_latitude(self, latitude: float) -> None:
		"""SCPI: SCENario:DF:MOVement:LATitude \n
		Snippet: driver.scenario.df.movement.set_latitude(latitude = 1.0) \n
		Use for defining the movement of an emitter (line trajectory) on a georeferenced map. Use to define the end-points of the
		line. Positive values represent °East. Negative values represent °West. \n
			:param latitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(latitude)
		self._core.io.write(f'SCENario:DF:MOVement:LATitude {param}')

	def get_longitude(self) -> float:
		"""SCPI: SCENario:DF:MOVement:LONGitude \n
		Snippet: value: float = driver.scenario.df.movement.get_longitude() \n
		Use for defining the movement of an emitter (line trajectory) on a georeferenced map. Use to define the end-points of the
		line. Positive values represent °East. Negative values represent °West. \n
			:return: longitude: float Range: -180 to 180
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:LONGitude?')
		return Conversions.str_to_float(response)

	def set_longitude(self, longitude: float) -> None:
		"""SCPI: SCENario:DF:MOVement:LONGitude \n
		Snippet: driver.scenario.df.movement.set_longitude(longitude = 1.0) \n
		Use for defining the movement of an emitter (line trajectory) on a georeferenced map. Use to define the end-points of the
		line. Positive values represent °East. Negative values represent °West. \n
			:param longitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(longitude)
		self._core.io.write(f'SCENario:DF:MOVement:LONGitude {param}')

	def get_north(self) -> float:
		"""SCPI: SCENario:DF:MOVement:NORTh \n
		Snippet: value: float = driver.scenario.df.movement.get_north() \n
		Sets the East/North coordinates of the emitter at the end of the movement. \n
			:return: north: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:NORTh?')
		return Conversions.str_to_float(response)

	def set_north(self, north: float) -> None:
		"""SCPI: SCENario:DF:MOVement:NORTh \n
		Snippet: driver.scenario.df.movement.set_north(north = 1.0) \n
		Sets the East/North coordinates of the emitter at the end of the movement. \n
			:param north: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(north)
		self._core.io.write(f'SCENario:DF:MOVement:NORTh {param}')

	def get_pitch(self) -> float:
		"""SCPI: SCENario:DF:MOVement:PITCh \n
		Snippet: value: float = driver.scenario.df.movement.get_pitch() \n
		Sets the angles of rotation in the corresponding direction. \n
			:return: pitch: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:PITCh?')
		return Conversions.str_to_float(response)

	def set_pitch(self, pitch: float) -> None:
		"""SCPI: SCENario:DF:MOVement:PITCh \n
		Snippet: driver.scenario.df.movement.set_pitch(pitch = 1.0) \n
		Sets the angles of rotation in the corresponding direction. \n
			:param pitch: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(pitch)
		self._core.io.write(f'SCENario:DF:MOVement:PITCh {param}')

	# noinspection PyTypeChecker
	def get_rframe(self) -> enums.MovementRframe:
		"""SCPI: SCENario:DF:MOVement:RFRame \n
		Snippet: value: enums.MovementRframe = driver.scenario.df.movement.get_rframe() \n
		Select the reference frame used to define the emitters coordinates. \n
			:return: rframe: WGS| PZ
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:RFRame?')
		return Conversions.str_to_scalar_enum(response, enums.MovementRframe)

	def set_rframe(self, rframe: enums.MovementRframe) -> None:
		"""SCPI: SCENario:DF:MOVement:RFRame \n
		Snippet: driver.scenario.df.movement.set_rframe(rframe = enums.MovementRframe.PZ) \n
		Select the reference frame used to define the emitters coordinates. \n
			:param rframe: WGS| PZ
		"""
		param = Conversions.enum_scalar_to_str(rframe, enums.MovementRframe)
		self._core.io.write(f'SCENario:DF:MOVement:RFRame {param}')

	# noinspection PyTypeChecker
	def get_rmode(self) -> enums.MovementRmode:
		"""SCPI: SCENario:DF:MOVement:RMODe \n
		Snippet: value: enums.MovementRmode = driver.scenario.df.movement.get_rmode() \n
		Defines the behavior of the moving object when the end of the trajectory is reached. \n
			:return: rmode: CYCLic| ROUNdtrip| ONEWay
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:RMODe?')
		return Conversions.str_to_scalar_enum(response, enums.MovementRmode)

	def set_rmode(self, rmode: enums.MovementRmode) -> None:
		"""SCPI: SCENario:DF:MOVement:RMODe \n
		Snippet: driver.scenario.df.movement.set_rmode(rmode = enums.MovementRmode.CYCLic) \n
		Defines the behavior of the moving object when the end of the trajectory is reached. \n
			:param rmode: CYCLic| ROUNdtrip| ONEWay
		"""
		param = Conversions.enum_scalar_to_str(rmode, enums.MovementRmode)
		self._core.io.write(f'SCENario:DF:MOVement:RMODe {param}')

	def get_roll(self) -> float:
		"""SCPI: SCENario:DF:MOVement:ROLL \n
		Snippet: value: float = driver.scenario.df.movement.get_roll() \n
		Sets the angles of rotation in the corresponding direction. \n
			:return: roll: float Range: -180 to 180
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:ROLL?')
		return Conversions.str_to_float(response)

	def set_roll(self, roll: float) -> None:
		"""SCPI: SCENario:DF:MOVement:ROLL \n
		Snippet: driver.scenario.df.movement.set_roll(roll = 1.0) \n
		Sets the angles of rotation in the corresponding direction. \n
			:param roll: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(roll)
		self._core.io.write(f'SCENario:DF:MOVement:ROLL {param}')

	def get_smoothening(self) -> bool:
		"""SCPI: SCENario:DF:MOVement:SMOothening \n
		Snippet: value: bool = driver.scenario.df.movement.get_smoothening() \n
		If a vehicle description file is loaded, activates smoothening. See method RsPulseSeq.Scenario.Localized.Movement.Vfile.
		value. \n
			:return: smoothening: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:SMOothening?')
		return Conversions.str_to_bool(response)

	def set_smoothening(self, smoothening: bool) -> None:
		"""SCPI: SCENario:DF:MOVement:SMOothening \n
		Snippet: driver.scenario.df.movement.set_smoothening(smoothening = False) \n
		If a vehicle description file is loaded, activates smoothening. See method RsPulseSeq.Scenario.Localized.Movement.Vfile.
		value. \n
			:param smoothening: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(smoothening)
		self._core.io.write(f'SCENario:DF:MOVement:SMOothening {param}')

	def get_speed(self) -> float:
		"""SCPI: SCENario:DF:MOVement:SPEed \n
		Snippet: value: float = driver.scenario.df.movement.get_speed() \n
		Sets the speed of the moving emitter. \n
			:return: speed: float Range: 0 to 5999
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:SPEed?')
		return Conversions.str_to_float(response)

	def set_speed(self, speed: float) -> None:
		"""SCPI: SCENario:DF:MOVement:SPEed \n
		Snippet: driver.scenario.df.movement.set_speed(speed = 1.0) \n
		Sets the speed of the moving emitter. \n
			:param speed: float Range: 0 to 5999
		"""
		param = Conversions.decimal_value_to_str(speed)
		self._core.io.write(f'SCENario:DF:MOVement:SPEed {param}')

	def get_spinning(self) -> float:
		"""SCPI: SCENario:DF:MOVement:SPINning \n
		Snippet: value: float = driver.scenario.df.movement.get_spinning() \n
		No command help available \n
			:return: spinning: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:SPINning?')
		return Conversions.str_to_float(response)

	def set_spinning(self, spinning: float) -> None:
		"""SCPI: SCENario:DF:MOVement:SPINning \n
		Snippet: driver.scenario.df.movement.set_spinning(spinning = 1.0) \n
		No command help available \n
			:param spinning: No help available
		"""
		param = Conversions.decimal_value_to_str(spinning)
		self._core.io.write(f'SCENario:DF:MOVement:SPINning {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.MovementType:
		"""SCPI: SCENario:DF:MOVement:TYPE \n
		Snippet: value: enums.MovementType = driver.scenario.df.movement.get_type_py() \n
		Defines the trajectory shape. \n
			:return: type_py: LINE| ARC| WAYPoint| TRACe
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.MovementType)

	def set_type_py(self, type_py: enums.MovementType) -> None:
		"""SCPI: SCENario:DF:MOVement:TYPE \n
		Snippet: driver.scenario.df.movement.set_type_py(type_py = enums.MovementType.ARC) \n
		Defines the trajectory shape. \n
			:param type_py: LINE| ARC| WAYPoint| TRACe
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.MovementType)
		self._core.io.write(f'SCENario:DF:MOVement:TYPE {param}')

	# noinspection PyTypeChecker
	def get_vehicle(self) -> enums.VehicleMovement:
		"""SCPI: SCENario:DF:MOVement:VEHicle \n
		Snippet: value: enums.VehicleMovement = driver.scenario.df.movement.get_vehicle() \n
		Assigns the selected icon. \n
			:return: vehicle: LVEHicle| SHIP| AIRPlane| STATionary| DEFault| CAR
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:VEHicle?')
		return Conversions.str_to_scalar_enum(response, enums.VehicleMovement)

	def set_vehicle(self, vehicle: enums.VehicleMovement) -> None:
		"""SCPI: SCENario:DF:MOVement:VEHicle \n
		Snippet: driver.scenario.df.movement.set_vehicle(vehicle = enums.VehicleMovement.AIRPlane) \n
		Assigns the selected icon. \n
			:param vehicle: LVEHicle| SHIP| AIRPlane| STATionary| DEFault| CAR
		"""
		param = Conversions.enum_scalar_to_str(vehicle, enums.VehicleMovement)
		self._core.io.write(f'SCENario:DF:MOVement:VEHicle {param}')

	def get_waypoint(self) -> str:
		"""SCPI: SCENario:DF:MOVement:WAYPoint \n
		Snippet: value: str = driver.scenario.df.movement.get_waypoint() \n
		Loads the selected waypoint file. To import and apply the files, send the command method RsPulseSeq.Scenario.Localized.
		Movement.ImportPy.set. \n
			:return: waypoint: string Filename or complete file path, incl. file extension. Waypoint files must have the extension *.txt, *.kml or *.xtd. Example files are provided with the software. For description, see 'Movement files'.
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:WAYPoint?')
		return trim_str_response(response)

	def set_waypoint(self, waypoint: str) -> None:
		"""SCPI: SCENario:DF:MOVement:WAYPoint \n
		Snippet: driver.scenario.df.movement.set_waypoint(waypoint = '1') \n
		Loads the selected waypoint file. To import and apply the files, send the command method RsPulseSeq.Scenario.Localized.
		Movement.ImportPy.set. \n
			:param waypoint: string Filename or complete file path, incl. file extension. Waypoint files must have the extension *.txt, *.kml or *.xtd. Example files are provided with the software. For description, see 'Movement files'.
		"""
		param = Conversions.value_to_quoted_str(waypoint)
		self._core.io.write(f'SCENario:DF:MOVement:WAYPoint {param}')

	def get_yaw(self) -> float:
		"""SCPI: SCENario:DF:MOVement:YAW \n
		Snippet: value: float = driver.scenario.df.movement.get_yaw() \n
		Sets the angles of rotation in the corresponding direction. \n
			:return: yaw: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:MOVement:YAW?')
		return Conversions.str_to_float(response)

	def set_yaw(self, yaw: float) -> None:
		"""SCPI: SCENario:DF:MOVement:YAW \n
		Snippet: driver.scenario.df.movement.set_yaw(yaw = 1.0) \n
		Sets the angles of rotation in the corresponding direction. \n
			:param yaw: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(yaw)
		self._core.io.write(f'SCENario:DF:MOVement:YAW {param}')

	def clone(self) -> 'Movement':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Movement(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Emitter:
	"""Emitter commands group definition. 14 total commands, 2 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("emitter", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import Mode
			self._mode = Mode(self._core, self._cmd_group)
		return self._mode

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 8 commands."""
		if not hasattr(self, '_state'):
			from .State import State
			self._state = State(self._core, self._cmd_group)
		return self._state

	def get_enable(self) -> bool:
		"""SCPI: SCENario:LOCalized:EMITter:ENABle \n
		Snippet: value: bool = driver.scenario.localized.emitter.get_enable() \n
		In a map-based sceanrio, enable selected item for calculation. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:LOCalized:EMITter:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SCENario:LOCalized:EMITter:ENABle \n
		Snippet: driver.scenario.localized.emitter.set_enable(enable = False) \n
		In a map-based sceanrio, enable selected item for calculation. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:LOCalized:EMITter:ENABle {param}')

	def get_value(self) -> str:
		"""SCPI: SCENario:LOCalized:EMITter \n
		Snippet: value: str = driver.scenario.localized.emitter.get_value() \n
		Assigns an existing emitter or an existing waveform, see method RsPulseSeq.Waveform.catalog and method RsPulseSeq.Emitter.
		catalog. \n
			:return: emitter: string
		"""
		response = self._core.io.query_str('SCENario:LOCalized:EMITter?')
		return trim_str_response(response)

	def set_value(self, emitter: str) -> None:
		"""SCPI: SCENario:LOCalized:EMITter \n
		Snippet: driver.scenario.localized.emitter.set_value(emitter = '1') \n
		Assigns an existing emitter or an existing waveform, see method RsPulseSeq.Waveform.catalog and method RsPulseSeq.Emitter.
		catalog. \n
			:param emitter: string
		"""
		param = Conversions.value_to_quoted_str(emitter)
		self._core.io.write(f'SCENario:LOCalized:EMITter {param}')

	def clone(self) -> 'Emitter':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Emitter(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Backlobe:
	"""Backlobe commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("backlobe", core, parent)

	def get_attenuation(self) -> float:
		"""SCPI: ANTenna:MODel:BACKlobe:ATTenuation \n
		Snippet: value: float = driver.antenna.model.backlobe.get_attenuation() \n
		Sets the attenuation of the back lobe. \n
			:return: attenuation: float Range: 0 to 100
		"""
		response = self._core.io.query_str('ANTenna:MODel:BACKlobe:ATTenuation?')
		return Conversions.str_to_float(response)

	def set_attenuation(self, attenuation: float) -> None:
		"""SCPI: ANTenna:MODel:BACKlobe:ATTenuation \n
		Snippet: driver.antenna.model.backlobe.set_attenuation(attenuation = 1.0) \n
		Sets the attenuation of the back lobe. \n
			:param attenuation: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(attenuation)
		self._core.io.write(f'ANTenna:MODel:BACKlobe:ATTenuation {param}')

	def get_enable(self) -> bool:
		"""SCPI: ANTenna:MODel:BACKlobe:ENABle \n
		Snippet: value: bool = driver.antenna.model.backlobe.get_enable() \n
		Enables the simulation of a back lobe. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('ANTenna:MODel:BACKlobe:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: ANTenna:MODel:BACKlobe:ENABle \n
		Snippet: driver.antenna.model.backlobe.set_enable(enable = False) \n
		Enables the simulation of a back lobe. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'ANTenna:MODel:BACKlobe:ENABle {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.BlType:
		"""SCPI: ANTenna:MODel:BACKlobe:TYPE \n
		Snippet: value: enums.BlType = driver.antenna.model.backlobe.get_type_py() \n
		Sets the shape of the back lobe pattern. \n
			:return: type_py: MIRRor| OMNidirect
		"""
		response = self._core.io.query_str('ANTenna:MODel:BACKlobe:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.BlType)

	def set_type_py(self, type_py: enums.BlType) -> None:
		"""SCPI: ANTenna:MODel:BACKlobe:TYPE \n
		Snippet: driver.antenna.model.backlobe.set_type_py(type_py = enums.BlType.MIRRor) \n
		Sets the shape of the back lobe pattern. \n
			:param type_py: MIRRor| OMNidirect
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.BlType)
		self._core.io.write(f'ANTenna:MODel:BACKlobe:TYPE {param}')
